<?php

/*
 *	Article System
 *	Online journal management tool written in PHP/MySQL/PostgreSQL.
 *	This code is available at http://sourceforge.net/projects/artsys
 *
 *	Copyright (C) 2001-2005 Jan Hnatek
 *	Distributed under the terms of the GNU General Public License
 *
 *	Date:	  05/08/2005
 *	Version:  0.6   	
 */

###############################################################################
# button : an abstract object ArtSys submenu buttons

/**
 *	An abstract class representing a button in ArtSys submenu (in module menu).
 *	
 *	@author		Jan Hnatek
 *	@package	admin
 */
class menu_button {
//---------------//

	// VARIABLES
	//

	/**	Parent section object to derive rights from. */
	//var $section;
	
	/**	The name="" value. */
	var $name;
	
	/**	Label of this button.
	 *	The text, which will be displayed on the button, ie. the value="".
	 */
	var $label;
	
	/** Minimal right to display this item. */
	var $right;
	
	/** Target module.
	 *	The link bound to this button will lead to given module.
	 */
	var $tmod;
	
	/** Target section.
	 *	The link bound to this button will lead to given section.
	 */
	var $tsec;

	/**	Image path.
	 */
	var $image;
	
	/** Script contents.
	 *	// in subclasses: Name of the script function, that will be used to redirect after pressing the button.
	 */
	var $script;


	// CONSTRUCTOR
	//
	
	/**	Constructor of the class.
	 *	This is just an example, it's recommended to override in subclasses to simplify input.
	 *	The target module is most likely the same, so if not, it should be set explicitly.
	 *	@param	$psec	Module object.
	 *	@param	$sec	Target section
	 *	@param	$label	Label of this button
	 *	@param	$name	Name of the button
	 *	@param	$script	Script for this button.
	 *	@see	display()
	 */
	function menu_button ($psec, $tsec, $label, $name, $script) {
		global $module;
		$this->tmod = $module;
		$this->tsec = $tsec;
		$this->image = "gui/img/icon0.gif"; // png
		$this->image = "<img \n\t\tsrc=\"{$this->image}\" width=\"32\" height=\"32\" border=\"0\"><br>";
		//$this->section = $psec;
		$this->label = $label;
		$this->name = $name;
		$this->script = $script;
		//$this->right = $this->section->get_right ($name);
		$this->right = $psec->get_right ($name);
	}


	// METHODS
	//

	/**	Echoes results of render() function.
	 *	@access public
	 */
	function display () {
		echo $this->render();
	}

	/**	Create link with querystring variables preserved.
	 *	@param	$post_vars	Array of variables to set.
	 *	@access	private
	 */
	function href ($post_vars) {
		global $config;
		if (!is_array ($post_vars))
			$post_vars = array ($post_vars);
		$href = "{$config["base_admin_url"]}/main.php";
		reset ($post_vars);
		list ($name, $val) = each ($post_vars);
		$href .= "?$name=$val";
		while (list ($name, $val) = each ($post_vars)) {
			$href .= "&$name=$val";
		}
		return $href;
	}
	
	/**	Reconstruct a link leading to the same page (preserve id and list values).
	 *	@access	private
	 */
	function self_href () {
		// FIXME: this is maybe not a very clean way to do this
		// preserve GET/POST vars 'list'/'id'
		return $this->href (array (
			"id" => isset ($_POST["id"]) ? $_POST["id"] :
					(isset ($_GET["id"]) ? $_GET["id"] : ''),
			"list" => isset ($_GET["list"]) ? $_GET["list"] : '',
		));
	}

	/**	Plain rendering function.
	 *	A 'virtual' function rendering the button.
	 *	This implementation of this function is the default,
	 *	it may be overridden in sub-classes.
	 *	This is just the default, or example.
	 *	It is called by display() function
	 *	@returns string
	 *	@access private
	 */
	function render_text () {
		$target = $this->self_href ();
		//return "<input \n\ttype=\"Button\" \n\tname=\"".$this->name."\" \n\tvalue=\"".$this->label."\" onclick=\"$this->script\">";
		return '<a href="'.$target.'" name="'.$this->name.'" onclick="'.$this->script.'">'.$this->label."</a>";
	}

	function render_image () {
		$this->label = $this->image . $this->label;
		return $this->render_text ();
	}
	
	function render () {
		return $this->render_image ();
	}
}

?>
