<?php

/*
 *	Article System
 *	Online journal management tool written in PHP/MySQL/PostgreSQL.
 *	This code is available at http://sourceforge.net/projects/artsys
 *
 *	Copyright (C) 2001-2005 Jan Hnatek
 *	Distributed under the terms of the GNU General Public License
 *
 *	Date:	  05/08/2005
 *	Version:  0.6   	
 */

###############################################################################
# button subclasses: default scripted button

/**
 *	@package	admin
 */
class link_button extends menu_button {
//-----------------------------------//

	var $script_args = '';

	/**	Custom constructor.
	 *	Script here is meant to be a function name ONLY.
	 *	@param string script Name of the script function, that will be used to redirect after pressing the button.
	 */
	function link_button ($psec, $tsec, $label, $name, $script, $args='') {
		menu_button::menu_button ($psec, $tsec, $label, $name, $script);
		$this->script_args = $args;
	}

	/*	<code>script</code> here is meant to be only a function name.
	 *	Still 'virtual'.
	 *	This implementation of this function is the default,
	 *	it may be overridden in sub-classes.
	 *	This is just the default, or example.
	 *	It is called by display() function
	 */
	function render_text () {
		$self_target = $this->self_href ();
		$remote_target = $this->href (array (
			"mod" => $this->tmod,
			"sec" => $this->tsec
		));
		$script = empty ($this->script_args) ? 
			"$this->script ('$remote_target')" :
			"$this->script ('$remote_target', ".$this->script_args.")";
		if ($this->script == "linkto")
			return '<a href="'.$remote_target.'" name="'.$this->name.'">'.$this->label."</a>";
		else
			return '<a href="javascript:'.$script.'" name="'.$this->name.'">'.$this->label."</a>";
	}
	
}	// class link_button


###############################################################################
# custom, often used predefined buttons:

/**
 *	@package	admin
 */
class button_reset extends link_button {
//------------------------------------//
	function button_reset (&$psec, $label) {
		menu_button::menu_button ($psec, null, $label, "reset", null);
	}
	function render_text () {
		return '<a href="javascript:document.items.reset()">'.$this->label.'</a>';
	}
}

/**
 *	@package	admin
 */
class button_new extends link_button {
//----------------------------------//
	function button_new (&$psec, $label) {
		menu_button::menu_button ($psec, "new", $label, "new", "linkto");
	}
}

/**
 *	@package	admin
 */
class button_edit extends link_button {
//-----------------------------------//
	function button_edit (&$psec, $label) {
		global $section;
		menu_button::menu_button ($psec, "edit", $label, "edit", "linkto");
		// NOTE: this will need revision when some other sections have lists
		$this->script = ($section == "list") ? "linklistto" : "linkto";
	}
}

/**
 *	@package	admin
 */
class button_delete extends link_button {
//-------------------------------------//
	function button_delete (&$psec, $label, $msg) {
		global $section;
		menu_button::menu_button ($psec, "delete", $label, "delete", "linkto");
		$this->script = ($section == "list") ? "confirmlinklistto" : "confirmlinkidto";
		$this->script_args = "'$msg'";
	}
}

/**
 *	@package	admin
 */
class button_save extends link_button {
//-----------------------------------//
	function button_save (&$psec, $label, $scriptfn=null) {
		global $section;
		menu_button::menu_button ($psec, "edit", $label, "save", "linkto");
		if (is_null ($scriptfn))
			$this->script = ($section == "list") ? "linklistto" : "linkto";
		else
			$this->script = $scriptfn;
	}
	function render_text () {
		if ($this->tsec != "")
			$tmp = "&sec=".$this->tsec;
		// 'Submit' doesn't pass on querystring variables, so we don't have to set them
		return '<a href="javascript:document.items.submit()">'.$this->label.'</a>';
	}
}

/**
 *	@package	admin
 */
class button_next extends button_save {
//-----------------------------------//
	function button_next (&$psec, $label, $scriptfn="") {
		button_save::button_save ($psec, $label, $scriptfn);
		$this->name = "next";
	}
}

// TODO : ??? class button_prev extends link_button {

/**
 *	@package	admin
 */
class button_done extends link_button {
//-----------------------------------//
	function button_done (&$psec, $label) {
		global $section;
		menu_button::menu_button ($psec, "list", $label, "done", "linkto");
		// NOTE: is this useless? always redirected to list, not from list, anyway
		$this->script = ($section == "list") ? "linklistto" : "linkto";
	}
}

?>
