<?php

/*
 *	Article System
 *	Online journal management tool written in PHP/MySQL/PostgreSQL.
 *	This code is available at http://sourceforge.net/projects/artsys
 *
 *	Copyright (C) 2001-2005 Jan Hnatek
 *	Distributed under the terms of the GNU General Public License
 *
 *	Date:	  05/08/2005
 *	Version:  0.6   	
 */

###############################################################################
# main : the main object of admin part of artsys

/**
 *	The main object of admin part.
 *	Module manager: registers the default module, then gets all
 *	available modules, parses their configuration and activates
 *	one according to session variables.
 *	Session variables and logout are also handled by this class.
 *
 *	@author		Jan Hnatek
 *	@package	admin
 */
class main {
//--------//

	// VARIABLES
	//
	
	/**	Name of the application. This is displayed in the title. */
	var $name;
	
	/**	Array of module objects. */
	var $modules;

	/** The name of the default module with system global settings. */
	var $default;
	
	/**	Index to $this->modules giving the active section. */
	var $active;

	/**	System global scripts. */
	var $scripts;
	
	/**	System global inline (possibly php preprocessed) scripts. */	
	var $inline_scripts;
	

	// CONSTRUCTOR
	//
	
	/**	Constructor of the main class.
	 *	Set the name as title of the pages and register modules according to given user object.
	 *	Set the currently active module.
	 *	
	 *	@param	$default_module	Name of the default module.
	 *	@param	$user	User object.
	 */
	function main ($default_module, &$user) {
		global $module, $config;
		//debug ("main()");
		$this->name = $config['project_name'];
		// import module globals
		$this->default = new module ($default_module);
		$this->default->import_messages ();
		$this->default->include_default ();
		// init: set up session & handle logout
		$this->init ();
		// import available modules
		$this->get_modules ($user);
		$this->get_scripts ();
	}


	// METHODS
	//

	/**	Set up session variables to handle module/section activation.
	 *	Handle logout.
	 */
	function init () {
		global $db, $config, $module, $section;
		//debug ('main->init()');
		// old values are in session or global $module/$section refs
		// requested values
		$mod =& $_GET['mod'];
		$sec =& $_GET['sec'];
		if (!empty ($mod)) {
			$module = $mod;
			// module change resets section
			$section = '';
		}
		if (!empty ($sec))
			$section = $sec;

		// handle logout
		if (($mod == 'logout') || ($sec == 'logout')) {
			// remove session information from DB
			$db->exec ("DELETE FROM Sessions WHERE id='$session_id';");
			// destroy session vars
			session_destroy ();
			// run away
			print "<SCRIPT>document.location.href='index.php'</SCRIPT>\n";
			exit;
		}
	}	
	
	/** Get all available modules.
	 */
	function get_modules () {
		global $module, $user;
		//debug ("main->get_modules()");
		// list of modules from ini
		$ini_modules =& $this->default->ini['modules'];
		// list of modules from user
		foreach ($ini_modules as $mname) {
			require_once INCLUDE_DIR ."/modules/$mname/class.module_$mname.php";
			eval ("\$tmp =& new module_$mname (\$mname);");
			if ($user->check_my ($tmp->right))
				$this->modules[$mname] =& $tmp;
//		adebug ($tmp->ini);
		}
		// activate a module
		conderror (is_array ($this->modules), msg('no modules available'));
		if (!in_array ($module, array_keys ($this->modules))) {
			$module = array_keys ($this->modules);
			$module = $module[0];
		}
		$this->modules[$module]->activate ();
		$this->active = $module;
	}

	/**	Get scripts for inclusion in the head of the page.
	 */
	function get_scripts () {
		global $module, $section;
		$this->scripts = array ();
		// scripts are in one place in base_admin_url/js
		while (list ($key, $script) = each ($this->default->ini['scripts']))
			if (is_numeric ($key) || $key == $module || $key == ":$section" || $key = "$module:$section")
				$this->scripts[] = $script;
		$this->inline_scripts = array ();
		while (list ($key, $script) = each ($this->default->ini['inline_scripts']))
			if (is_numeric ($key) || $key == $module || $key == ":$section")
				$this->inline_scripts[] = $script;
	}

	/**	The main menu display function.
	 *	Display links to/of all registered modules.
	 */
	function menu_modules () {
		global $gui;
		// prepare main menu items arrays
		//debug ("main->_menu()");
		$items = array ();
		foreach ($this->modules as $module)
			array_push ($items, $module->main_link ());
		$gui->menu_modules ($items, msg('modules'));
	}

	/**	Display some info in the main menu (login info, time, logout button).
	 */
	function menu_info () {
		global $config, $gui;
		// if active_module->section->open_form, we shouldn't output <form> for timer, otherwise yes
		if ($this->modules[$this->active]->section_menu->open_form)
			$info = $this->login_info ();
		else
			$info = '<form name="timecount" action="">'. $this->login_info () .'</form>';
		$items = array (
			$info,
			'<a href="'.$config['base_url'].'/index.php">'. msg('public pages') .'</a>',
			'<a href="'. print_url ("{$config['base_admin_url']}/main.php", array ('thelp')). '">'. msg('show help') .'</a>',
			'<a href="'.$config['base_admin_url'].'/main.php?mod=logout&sec=logout">'. msg('logout') .'</a>'
		);
		$gui->menu_info ($items);
	}

	function get_help () {
		global $module, $section, $user;
		//debug ("main->get_help()");
		// test if localized help exists
		$file = INCLUDE_DIR ."/modules/$module/help/$section.{$user->language}.php";
		if (file_exists ($file))
			return $this->read_help ($file);
		// otherwise try default
		$file = INCLUDE_DIR ."/modules/$module/help/$section.php";
		return file_exists ($file) ? $this->read_help ($file) : null;
	}
	
	/**	Returns currently active module.
	 *	@access	public
	 *	@return	object module
	 */
	function get_active () {
		return $this->modules[$this->active];
	}

	/**	Returns the title for the pages.
	 *	Intended to be used in &lt;title&gt; tag.
	 *	@return string
	 */
	function get_title () {
		global $module, $section;
		return "{$this->name} - $module:$section";
	}

	/**	Render login information (user, time, group ??)
	 *	@return	string
	 */
	function login_info () {
		global $user_name, $gui;
		setlocale (LC_TIME, 'C');
		return "$user_name " . strftime ('%X') . '<br>' . msg('session') .'&nbsp;'. $this->_time_counter ();
	}

	/** Read given file (help.php) file and return contents.
	 */
	function read_help ($file) {
		return implode ('', file ($file));
	}

	/**	Returns time counter form <code>&lt;input&gt;</code> tag.
	 *	@return string
	 */
	function _time_counter () {
		global $browser;
		return '<input class="timecounter" size="5" name="timer">';
	}

}	// class main

?>
