<?php

/*
 *	Article System
 *	Online journal management tool written in PHP/MySQL/PostgreSQL.
 *	This code is available at http://sourceforge.net/projects/artsys
 *
 *	Copyright (C) 2001-2005 Jan Hnatek
 *	Distributed under the terms of the GNU General Public License
 *
 *	Date:	  05/08/2005
 *	Version:  0.6   	
 */

###############################################################################

/**
 *	Module - parent class for included modules.
 *
 *	@author		Jan Hnatek
 *	@package	admin
 */
class module {
//----------//

	// VARIABLES
	//

	/** Name of this module. */
	var $name;

	/**	This is set to true when activating this module.
	 *	@see	activate()
	 */
	var	$active;
	
	/** Section object with description of the submenu. */
	var $section_menu;
	
	/** Form object, if any. */
	var $form;
	
	/** Minimal access right for this module. */
	var $right;
	
	/** Module initialization data. Read from modules.ini. */
	var $ini;

	/**	Module (inline) scripts. */
	var $scripts;
	

	// CONSTRUCTOR
	//
	
	/**	Set module name, non-active and read configuration.
	 *	@param	$name	Module name.
	 */
	function module ($name) {
		//debug ("module($name)");
		$this->name = $name;
		$this->active = false;
		$this->ini = parse_ini_file (INCLUDE_DIR ."/modules/{$this->name}/module.ini", true);
		$this->right = isset ($this->ini["right"]) ? $this->ini["right"] : false;
	}


	// METHODS
	//

	/**	Activate this module, ie. import all relevant data.
	 */
	function activate () {
		//debug ("module->activate({$this->name})");
		$this->active = true;
		$this->import_messages ();
		$this->include_default ();
		$this->get_section_menu ();
		$this->get_scripts ();
	}
	
	/**	Import messages for this module and merge them with system-wide <code>$MSG</code> array.
	 */
	function import_messages () {
		global $config, $user, $MSG;
		$tmp = parse_ini_file (INCLUDE_DIR ."/modules/{$this->name}/lang/{$config['lang']}.ini", false);
		if (strtolower ($config['charset']) != 'iso-8859-2') {
			if (function_exists ('recode_string')) {
				foreach ($tmp as $key => $val)
					$tmp[$key] = recode ("iso-8859-2..{$config['charset']}", $val);
			} /* Notify users of 'recode' posssibility
			elseif ($user['lang'] != 'en') {
				warning ("Note: install 'recode' library if the l10n menus get garbled and the page contents not.");
			} */
		}
		$MSG = array_merge ($MSG, $tmp);
	}

	/**	Include default module tools (if any).
	 */
	function include_default () {
		$file = INCLUDE_DIR ."/modules/{$this->name}/default.php";
		if (file_exists ($file))
			require_once ($file);
	}
	
	/**	Get scripts for inline inclusion (section dependant).
	 */
	function get_scripts () {
		global $section;
		$this->scripts = array ();
		// scripts are in one place in base_admin_url/js
		if (isset ($this->ini[":$section.scripts"]))
			$this->scripts = explode (",", $this->ini[":$section.scripts"]);
		return $this->scripts;
	}

	/**	Create form if current section has one.
	 */
	function create_form () {
		global $module, $section;
		// form_process
		if (isset ($this->ini[":$section.form"])) {
			$class = "form_{$module}_{$this->ini[":$section.form"]}";
			if (class_exists ($class))
				return eval ("\$this->form = new $class (\$this->section_menu, \$class);");
			else
				failexit ("class not found: ". q($class));
		}
		// form_wizard
		if (isset ($this->ini[":$section.wizard"])) {
			$class = "form_wizard_{$module}_{$this->ini[":$section.wizard"]}";
			if (class_exists ($class))
				return eval ("\$this->form = new $class (\$this->section_menu, \$class);");
			else
				failexit ("class not found: ". q($class));
		}
	}

	/** Unset session variables of all wizards in this module.
	 */
	function reset_wizards () {
		global $module;
		while (list ($key, $val) = each ($this->ini)) {
			if (preg_match ("/^:.*\.wizard/", $key)) {
				// session var hardcoded
				$svar = "form_wizard_{$module}_{$this->ini[$key]}_state";
				unset ($_SESSION[$svar]);
				session_unregister ($svar);
			}
		}
	}

	/**	Get section menu from external file.
	 */
	function get_section_menu () {
		global $module, $config;
		//debug ("module->get_section_menu({$this->name})");
		$this->section_menu =& $this->menu ();
	}

	/**	Return access right according to ini.
	 *	If not set in ini, use the right of this object.
	 *	That makes it a tree structure of rights, where leaves have highest priority.
	 */
	function get_right ($path) {
		//debug ("module->get_right(:$path)");
		return isset ($this->ini[":$path"]) ? $this->ini[":$path"] : $this->right;
	}
	
	/**	Tells whether given value is set in ini. */
	function isset_right ($path) {
		//debug ("module->isset_right(:$path)");
		return isset ($this->ini[":$path"]);
	}

	/**	Renders the "submenu", ie. the menu of this module.
	 *	The menu is defined by menu() function.
	 */
	function menu_sections () {
		global $section, $gui, $config;
		//debug ("module->display({$this->name})");
		// get 'menu_button' array corresponding to current section
		$active = $this->section_menu->get_buttons ();
		// prepare arrays for the menu
		$items = array ();
		for ($i=0; $i < count ($active); $i++) 
			array_push ($items, $active[$i]->render ());
		// render menu
		$gui->menu_sections ($items, $this->section_menu->open_form, msg("sections"));
	}

	/**	Return current include file name.
	 *	If it does not exists, return the default include filed from default module.
	 */
	function get_include () {
		$include_file = INCLUDE_DIR ."/modules/{$this->name}/include/{$this->section_menu->include_file}";
		if (empty ($include_file) || (!file_exists ($include_file)))
			$include_file = INCLUDE_DIR ."/modules/_default/include/template.php";
		//debug ("module->get_include()<br>$include_file");
		return $include_file;
	}
	
	/**	Echoes a self-pointing anchor tag.
	 */
	function main_link () {
		global $module, $config;
		if ($module != $this->name)
			return "<a href=\"{$config["base_admin_url"]}/main.php?mod={$this->name}\">".msg($this->name)."</a>";
		else
			return msg($this->name);
	}

}	// class

?>
