<?php

/*
 *	Article System
 *	Online journal management tool written in PHP/MySQL/PostgreSQL.
 *	This code is available at http://sourceforge.net/projects/artsys
 *
 *	Copyright (C) 2001-2005 Jan Hnatek
 *	Distributed under the terms of the GNU General Public License
 *
 *	Date:	  05/08/2005
 *	Version:  0.6   	
 */

###############################################################################
# form_item : abstract object wrappers for HTML forms inputs


/**
 *	An abstract class representing generic form control<br>
 *	based on Yuri Makassiouk's (&lt;racer@bfpg.ru&gt;) FormControl
 *	
 *	@author		Jan Hnatek
 *	@package	forms
 */
class form_item {
//-------------//

	// VARIABLES
	//
	/**	Logical name of a control.
	 *	Corresponds to name of a data element in the containing form.
	 * 	@see		$form
	 */
	var $name;
	  
	/**	References the containing form's object.
	 *	Establishes a link between object representing a control of a form and object representing the form.
	 */
	var $form;
	 
	/**	Access right for this item. */
	var $right;
	
	/**	Holds value for a control that the object will represent. */
	var $value;
	
	/**	Holds a string with control's attributes.
	 *	This would normally be a string containing some formatting attributes that will be embedded in 
	 *	the control's html tag to refine its appearance and/or behaviour.
	 */
	var $attributes;
	
	/**	Holds a copy of containing form's name. */
	var $form_name;
	
	/**	Name of the html input that this object will represent. Do not confuse with $name!.
	 *	It is a value for the name="" attribute, how it will appear in form's html.
	 */
	var $input_name;

	/**	Messages - keys to $MSG for msg(). */
	var $msg_description;
	var $msg_help;


	// CONSTRUTOR
	//
	/**	Constructor of the class.
	 *	Given a reference to a containing form's object, examines some its values. 
	 *	Sort of, tunes in the containing form. Then puts control's code to the output stream by calling 
	 *	display() member function
	 *	@param	$aform form_process A reference to the object representing containing form
	 *	@param	$aname Logical name for the control
	 *	@param	$avalue Value that initializes the control when it is displayed for the first time
	 *	@param	$aattributes Usually would be a fragment of input's tag 
	 *			containing some attributes refining control's appearance and behaviour
	 */
	function form_item ($aform, $aname, $avalue='', $aattributes='') {
		$this->name = $aname;
		$this->form = $aform;
		$this->right = $this->form->get_right ($aname);
		//debug ($this->right);
		$this->attributes = $aattributes;
		$this->form_name = $aform->name;
		$this->input_name = sprintf("%s%s[%s]", $this->form->field_prefix, $this->form_name, $this->name);
		$this->set_value ($avalue);
		//debug ("new value of $aname:".$this->value."/".$avalue);
		$this->msg_description = "form {$this->name}";
		$this->msg_help = "form {$this->name} help";
	}

	// METHODS
	//
	/**	This is the default way the values are set.
	 *	It has been separated, so that it can be easily overriden in subclasses.
	 */
	function set_value ($value) {
		if ($this->form->first_time)
			$this->value = addslashes ($value);
		else
			$this->value = isset ($this->form->values[$this->name]) ?
				$this->form->values[$this->name] : addslashes ($value);
	}
	
	/**	Echoes name of the input.
	 *	Why do we need it? Probably for a shortcut..
	 */
	function input_name () {
		echo $this->input_name;
	}
	
	/**	Echoes results of render() function.
	 *	This function is called by constructor, so that applications may place control in html by simply instantiating a required class
	 *	@param	$show_help	Boolean control of help output.
	 */
	function display ($show_help=true) {
		echo $this->render ();
		if ($show_help && msg_exists ($this->msg_help)) {
			echo "&nbsp;";
			help ($this->help());
		}
	}

	/**	Check module ini and return if this item should be visible.
	 *	Is not meant to be used for the input item only, but for the description and help too.
	 */
	function visible () {
		global $user;
		switch ($this->right) {
		case "none": return true; break;
		case "hide": return false; break;
		default:
			return $user->check_my ($this->right);
		}
	}

	/**	Print out description message. */
	function description () {
		echo msg ($this->msg_description);
	}

	/**	Return help message. */
	function help () {
		return msg ($this->msg_help);
	}
	
	/**	An abstract function rendering a control.
	 *	This function must be overridden in sub-classes to render  the control's html code. It is called by Display() function
	 */
	function render () {}
		//abstract
	}

?>
