<?php

/*
 *	Article System
 *	Online journal management tool written in PHP/MySQL/PostgreSQL.
 *	This code is available at http://sourceforge.net/projects/artsys
 *
 *	Copyright (C) 2001-2005 Jan Hnatek
 *	Distributed under the terms of the GNU General Public License
 *
 *	Date:	  05/08/2005
 *	Version:  0.6   	
 */

###############################################################################
# form_items : simple abstract object wrappers for HTML forms inputs


/**
 *	Class representing a plaintext value (NOT a *form* item, just a string).<br>
 *	The value is NOT passed on.<br>
 *
 *	@parent		form_item
 *	@package	forms
 */
class form_plaintext extends form_item {
//------------------------------------//
	function render() {
    	return htmlspecialchars (stripslashes ($this->value));
	}
}

/**
 *	Class representing a plaintext value, that is passed on with the form.<br>
 *
 *	@parent	form_item
 *	@package	forms
 */
class form_string extends form_item {
//---------------------------------//
	function render() {
    	return htmlspecialchars (stripslashes ($this->value)) .
    	"<input type=\"Hidden\" name=\"{$this->input_name}\" value=\"". stripslashes (htmlspecialchars ($this->value)) ."\">";
	}
}

/**
 *	Class representing a hidden control.
 *
 *	@parent	form_item
 *	@package	forms
 */
class form_hidden extends form_item {
//---------------------------------//
	function render() {
    	return "<input type=\"Hidden\" name=\"{$this->input_name}\" value=\"". stripslashes (htmlspecialchars ($this->value)) ."\">";
	}
}

/**
 *	Class representing a text control.<br>
 *	Set size="" in attributes for this class !
 *
 *	@parent	form_item
 *	@package	forms
 */
class form_text extends form_item {
//-------------------------------//
	function render() {
    	return "<input type=\"Text\" name=\"{$this->input_name}\" value=\"".
		htmlspecialchars (stripslashes ($this->value)) ."\" {$this->attributes}>";
	}
}

/**
 *	Class representing a password text control.<br>
 * 	It just doesn't set the value="" attribute for obvious reasons.
 *	Set size="" in attributes for this class !
 *
 *	@parent	form_item
 *	@package	forms
 */
class form_password extends form_item {
//-----------------------------------//
	function render() {
		return "<input type=\"Password\" name=\"{$this->input_name}\" {$this->attributes}>";
	}
}

/**
 *	Class representing a text area.<br>
 *	Set rows="" and cols="" in attributes for this class !
 * 
 *	@parent	form_item
 *	@package	forms
 */
class form_textarea extends form_item {
//-----------------------------------//
	function render() {
		return "<textarea name=\"{$this->input_name}\" {$this->attributes}>". stripslashes (htmlspecialchars ($this->value)) ."</textarea>";
	}
}

/**
 *	Class representing a checkbox
 * 
 *	@parent	form_item
 *	@package	forms
 */
class form_checkbox extends form_item {
//-----------------------------------//
	/** Unset checkbox when not for the first time means it was unset, ie. '0'.
	 */
	function set_value ($value) {
		if ($this->form->first_time)
			$this->value = addslashes ($value);
		else
			$this->value = isset ($this->form->values[$this->name]) ?
				$this->form->values[$this->name] : '0';
	}
	/**	Custom render.
	 *	Checkbox does not export its value parameter, it's either "on" or anything.
	 */
	function render() {
		// NOTE: this shouldn't be here! but it's easier this way :(
		// (see admin style.css "TABLE.form INPUT")
		if (!preg_match ("/class=/", $this->attributes))
			$this->attributes .= ' class="checkbox"';
		return ($this->value == "on" || $this->value == "1") ?
			"<input type=\"CheckBox\" checked name=\"{$this->input_name}\" {$this->attributes}>" :
			"<input type=\"CheckBox\" name=\"{$this->input_name}\" {$this->attributes}>";
	}
}

/**
 *	Class representing a button
 * 
 *	@parent	form_item
 *	@package	forms
 */
class form_button extends form_item {
//---------------------------------//
	function render() {
    	return "<input type=\"Button\" name=\"{$this->input_name}\" value=\"{$this->value}\" {$this->attributes}>";
	}
}

/**	
 *	Class representing a submit button.
 *	Submit doesn't alter it's value="" (ie. button's label) attribute after submitting.
 *	
 *	@parent	form_item
 *	@package	forms
 */
class form_submit extends form_item {
//---------------------------------//
	function set_value (&$value) {
		$this->value = $value;
	}
	function render() {
    	return "<input type=\"Submit\" name=\"{$this->input_name}\" value=\"{$this->value}\" {$this->attributes}>";
	}
}

/**
 *	Class representing a select box.
 * 
 *	@parent	form_item
 *	@package	forms
 */
class form_select extends form_item {
//---------------------------------//

	/**	Array of options, which can be selected through this select box. */
	var $options = array ();
	
	/**	Constructor of the class.
	 *	Accepts the $options array among other params from form_item contructor. 
	 *	@param	$options	An array of options to use.
	 *	@see	form_item
	 *	@see	display()
	 */
	function form_select ($aform, $aname, $options, $avalue='', $aattributes='') {
		form_item::form_item ($aform, $aname, $avalue, $aattributes);
		$this->options = $options;
	}
	
	/**	Custom set_value routine. */
	function set_value (&$value) {
		if ($this->form->first_time)
			$this->value = $value;
		else
			$this->value = isset ($this->form->values[$this->name]) ? $this->form->values[$this->name] : $value;
	}
	
	/**	Custom select box rendering routine. */
	function render() {
		// render_select_box (name, options, selected, attributes)
		render_select_box ($this->input_name, $this->options, $this->value, $this->attributes);
	}

} // class

?>
