<?php

/*
 *	Article System
 *	Online journal management tool written in PHP/MySQL/PostgreSQL.
 *	This code is available at http://sourceforge.net/projects/artsys
 *
 *	Copyright (C) 2001-2005 Jan Hnatek
 *	Distributed under the terms of the GNU General Public License
 *
 *	Date:	  05/08/2005
 *	Version:  0.6   	
 */

###############################################################################

/**	
 *	Form wizard - form_process sequence control.
 *	
 *	@author		Jan Hnatek
 *	@package	forms
 */
class form_wizard {
//---------------//

	// VARIABLES
	//
	/** Name of this wizard */
	var $name;
	/**	Section object this form belongs to. */
    var $section;
	/**	Current wizard state */
	var $current;
	/** Name of the session variable */
	var $session_var;
	/** State data .. structure:
		array ( array ( "class" => "classname", "url" => "http://...." ),
				array ( "class" => "classname", "url" => "http://...." ),
			);
	 */
	var $states = array ();

	// CONSTRUCTOR
	//
	/**	Create the wizard sequence based on given state data, instatiate proper class if present.
	 *	@param	$name
	 *	@param	$in_states	
	 *	@param	$session_var
	 */
	function form_wizard (&$section, $name) {
		debug ("constructor: $name");
		$this->section = $section;
		$this->right = $section->get_right ($name);
		$this->name = $name;

		// paranoia: double check that form won't be displayed if alert_run fails
		if (!$this->prepare ())
			return false;
		// $this->states should be set in prepare ()
		if (empty ($this->states))
			failexit ("wizard not set up: {$this->name}");

		// session var hardcoded: used in module->reset_wizards ()
		$this->session_var = $this->name."_state";
		if (!isset ($_SESSION[$this->session_var])) {
			//session_register ($this->session_var);
			$_SESSION[$this->session_var] = 0;
		}
		// check current state
		$this->current = $_SESSION[$this->session_var];
		$this->check_current ();
		$this->instantiate ();
	}

	// METHODS
	//
	/**	Check correctness of current state.
	 *	Possible values : numeric {0 .. count($states)}.
	 */
	function check_current () {
		// FIXME: ? loop by default ?
		if (!is_numeric ($this->current) || $this->current >= count ($this->states)) {
			$this->current = 0;
			$_SESSION[$this->session_var] = 0;
		}
	}
	
	/** Create an instance of current form.
	 *	The forms are suggested to not display themselves after saving data.
	 */
	function instantiate () {
		// instantiate the form_process(_sequence) class
		$current = $this->states[$this->current];
		if (key ($current) == "terminator") {
			$text = $current["terminator"]["text"];
			$var = $current["terminator"]["var"];
			debug ("form_wizard state: ".$this->current." / terminator");
			new form_wizard_terminator ($this->section, "form_wizard_terminator", $this, $text, $var);
		} else {
			$classname = $current['class'];
			debug ("form_wizard state: ".$this->current." / $classname");
			if (class_exists ($classname))
				eval ("new \$classname (\$this->section, \$classname, \$this);");
			else
				failexit ("class $classname not found ...");
		}
	}
	
	/** Advance in wizard and instantiate the next form.
	 */
	function advance () {
		$old = $this->current++;
		$this->check_current ();
		debug ('<span style="color:red">ADVANCING to </span>'.$this->current);
		$_SESSION[$this->session_var] = $this->current;
		// prevent loop when we have (accidentally) only one item
		if ($old != $this->current)
			$this->instantiate ();
	}
	
	/**	Return current state.
	 */
	function get_state () {
		return $this->current;
	}

} // class

?>
