<?php

/*
 *	Article System
 *	Online journal management tool written in PHP/MySQL/PostgreSQL.
 *	This code is available at http://sourceforge.net/projects/artsys
 *
 *	Copyright (C) 2001-2005 Jan Hnatek
 *	Distributed under the terms of the GNU General Public License
 *
 *	Date:	  05/08/2005
 *	Version:  0.6   	
 */

###############################################################################
# rights : rights checking object for admin part of artsys

/**
 *	User rights management for artsys
 *	
 *	@author		Jan Hnatek
 */
class user {
//--------//

	// VARIABLES
	
	/**	User id of current user.
	 * 	@var		int
	 * 	@access		private
	 */
	 var $id;
	 var $realname;
	 var $username;
	 var $email;
	 var $signature;
	 var $blocked;
	 var $group;
	 var $rights = array ();
	 var $language;
	 var $show_help;
	 var $page_size;

	// CONSTRUCTOR

	/**	Constructor of the rights class.
	 *	Fill in user information and set rights array according to db.
	 *
	 *	@param	$id int User id of this user.
	 *	@access	public
	 */
	function user ($id) {
		global $db;
		$this->id = $id;
		// get user information from db
		$RS = $db->exec ("SELECT U.id, U.name as uname, U.username, U.email, U.signature, U.blocked, 
			U.language, U.show_help, U.page_size, G.*
			FROM Users U, Ugroups G WHERE (U.id='$id') AND (U.ugroup=G.id);"); // , 1
		// TODO: unify these messages
		test ($RS, "internal error: failed to get user information<br>\n");

		// distribute values
		$user = $db->get_result_object ();
		$this->realname = $user->uname; // U.name
		$this->username = $user->username;
		$this->email = $user->email;
		$this->signature = $user->signature;
		$this->blocked = $user->blocked;
		$this->language = $user->language;
		$this->show_help = $user->show_help;
		// set help based on session/get
		if (isset ($_GET['thelp'])) {
			$_SESSION['help'] = isset ($_SESSION['help']) ?  !$_SESSION['help'] : !$this->show_help;
			$this->show_help = $_SESSION['help'];
		} elseif (isset ($_SESSION['help']))
			$this->show_help = $_SESSION['help'];
		$this->page_size = $user->page_size;
		$this->group = $user->name;	// G.name
		$this->rights = array (
		    'a_create'	=> $user->a_create,	      # submit new articles
		    'a_correct'	=> $user->a_correct,      # edit and correct else's articles
		    'a_approve'	=> $user->a_approve,      # sign an article as finished for next issue, edit approved articles
		    'a_publish'	=> $user->issues,		  # issue management, article publishing
		    'users'		=> $user->users,	      # users modification (add, delete, block)
			'agroups'	=> $user->agroups,	      # group modification (add, delete)
			'admin'		=> $user->admin,          # admin tasks
			);
	}

	// METHODS
	
	/**	Rights checking routine.
	 *	Returns true/false depending on current users rights on given subject.<br>
	 *	List of rights:<br>
		"a_create"	submit new articles<br>
	    "a_correct"	edit and correct else's articles<br>
	    "a_approve"	sign an article as finished for next issue, edit approved articles<br>
	    "issues"	issue management<br>
	    "users"		users modification (add, delete, block)<br>
		"agroups"	group modification (add, delete)<br>
		"admin"		admin tasks<br>
	 *	@param	$right string Subject to check rights of.
	 *	@access	public
	 *	@return	bool
	 */
	function check_my ($right) {
		return ($this->rights[$right] == 1);
	}
	
	/**	Returns modules array depending on user rights.
	 *	Used by the <code>main</code> class.<br>
	 *	@return	<code>$modules</code> .. is an associative array with (section, module_name) pairs.
	 *	@access	public
	 */
	function get_modules () {
		$modules = array ();
		//if ($this->rights["a_create"] || $this->rights["a_correct"] || $this->rights["a_approve"])
			$modules["articles"] = "articles";
		if ($this->rights["agroups"])
			$modules["groups"] = "groups";
		if ($this->rights["issues"])
			$modules["issues"] = "issues";
		if ($this->rights["a_create"])
			$modules["images"] = "images";
		if ($this->rights["users"])
			$modules["users"] = "users_admin";
		else
			$modules["users"] = "users";
   		if ($this->rights["admin"])
			$modules["admin"] = "admin";
		return $modules;
	}

}	// class main

?>
