<?php

/*
 *	Article System
 *	Online journal management tool written in PHP/MySQL/PostgreSQL.
 *	This code is available at http://sourceforge.net/projects/artsys
 *
 *	Copyright (C) 2001-2005 Jan Hnatek
 *	Distributed under the terms of the GNU General Public License
 *
 *	Date:	  05/08/2005
 *	Version:  0.6   	
 */

###############################################################################


/**
 *	Client part support for Article System.<br>
 *	Functions to handle articles on the client side.
 *
 *	@author	Jan Hnatek
 *	@package client
 */
class client_articles extends client_entity {

    // VARIABLES
    //
	var $a_articles;
	var $a_images;

	var $article;

	var $error;

	// CONSTRUCTOR
	//
	function client_articles (&$art, &$ima) {
		global $db;
		if (!is_object ($db))
			return false;
    	$this->a_articles = $art;
		$this->a_images = $ima;

		// satisfy parent class
		$this->a_entity =& $this->a_articles;
	}


	// ARTICLE METHODS
	//
	/**	Return detailed article data of given article.
	 *	Depending on the flags, it returns articles from ISSUE_CURRENT issue only, ISSUE_ARCHIVED issues, or both .. ISSUE_VISIBLE.<br>
	 *	To request even the articles published in groups, GROUP_VISIBLE should be used.<br>
	 *	TO get any published article, either from issues or from groups, use VISIBLE.
	 *	Following are valid:<br>
	 *		ISSUE_ARCHIVED | ISSUE_CURRENT == ISSUE_VISIBLE<br>
	 *		ISSUE_VISIBLE | GROUP_VISIBLE == VISIBLE<br>
	 *	Usage of INVISIBLE parameter should require active session, it does not check article state.
	 *	@param	$id	Id of an article
	 *	@param	$flags	One of the folowing { ISSUE_CURRENT, ISSUE_ARCHIVED, ISSUE_VISIBLE, GROUP_VISIBLE, VISIBLE, INVISIBLE }
	 *	@return associative array
	 */
	function get ($id, $flags=VISIBLE, $what='A.id, A.title, A.subtitle, A.menu_title, A.preview, 
		A.content, A.sources, A.signature, A.counter, A.rating, A.num_rated, 
		A.display_extras') {
		switch ($flags) {
			case ISSUE_CURRENT: return $this->get_special ($id, "(I.current='1')", $what);
			case ISSUE_ARCHIVED: return $this->get_special ($id, "(I.archived='1')", $what);
			case ISSUE_VISIBLE:
				return $this->article = $this->get_special ($id, "(I.current='1' OR I.archived='1')", $what);
			case GROUP_VISIBLE:
				$what = preg_replace ("/A\./", "", $what);
				return $this->article = $this->a_articles->get_one ($what, "WHERE id='$id' AND published_on IS NOT NULL AND issue IS NULL");
			case VISIBLE:
				$what = preg_replace ("/A\./", "", $what);
				return $this->article = $this->a_articles->get_one ($what, "WHERE id='$id' AND published_on IS NOT NULL");
			case INVISIBLE:
				$what = preg_replace ("/A\./", "", $what);
				return $this->article = $this->a_articles->get_one ($what, "WHERE id='$id'");
		}
	}

	/**	Return specified part of last loaded (with get_article) article.
	 *	@param	$what	Column name from Articles.
	 *	@return string
	 */
	function get_adata ($what) {
 		//if (!$this->article) {
		return $this->article[$what];
	}

	/**	Return list of related articles.
	 *	The list is for article returned by the last get_article() call.
	 *	@return array
	 */
	function get_related ($id='') {
		if (empty ($id))
			$id = $this->article['id'];
		if (is_numeric ($id))
			return $this->a_articles->get_related ($id, 'id, title, menu_title');
   		else
			return false;
	}

	/**	Return next article in an issue from given article, if any.
	 *	@return array
	 */
	function get_next ($id='', $what='id, title') {
		if (empty ($id))
			$id = $this->article['id'];
		if (is_numeric ($id))
			return $this->a_articles->get_next ($id, $what);
   		else
			return false;
	}

	/**	Return previous article in an issue from given article, if any.
	 *	@return array
	 */
	function get_previous ($id='', $what='id, title') {
		if (empty ($id))
			$id = $this->article['id'];
		if (is_numeric ($id))
			return $this->a_articles->get_previous ($id, $what);
   		else
			return false;
	}

	/**	Test if given article id is from current issue.
	 *	Use to prevent displaying of non-public articles.
	 *	@param	$id	Id of an article
	 *	@return string
	 */
	function is_current ($id) {
		// TODO
		return true;
	}

	/**	Return detailed article data of given article.
	 *	Restriction to articles is specified as parameter.<br>
	 *	@param	$id	Id of an article
	 *	@param	$restrict Restrictions to apply.
	 *	@param	$what Columns to return: select from { Articles A, Users U, Issues I }. Comma separated.
	 *	@access	private
	 *	@return associative array
	 */
	function get_special ($id, $restrict, $what='A.id, A.title, A.subtitle, A.preview, A.content, A.sources, A.signature') {
		global $db;
		$result = array ();
		// this is from get_article()
		;
		// NOTE: could be specified by issue.namem it's unique
		// "SELECT A.id, A.title, U.name FROM Articles A, Users U WHERE A.author=U.id AND A.issue = '$iname'"
		// NOTE: this routine is modification od db_articles->get_issue(), so see that first
	 	// Note: A.iorder must appear in target list ($what) when using DISTINCT
		// NOTE: deleted DISTINCT, so that A.iorder is not obligatory
		$rs = $db->exec ("SELECT $what FROM Articles A, Users U, Issues I
			WHERE (A.author=U.id) AND (A.issue=I.id) AND $restrict AND (A.id='$id')
			ORDER BY A.iorder"); //, 1);
		if (!$rs) {
			$this->error = $db->report ("select fail");
			return $this->article = false;
		}
		return $this->article = $db->get_result_array ();
	}
	
	/**	Return articles according to rating (with non-zero rating), sorted from best to worst.
	 *	@param	$limit	Number of articles to return.
	 *	@param	$what	Properties to get.
	 */
	function get_by_rating ($limit, $what="A.id, A.title, A.rating, A.num_rated", $where="") {
		global $db;
		if (!is_numeric ($limit))
			return false;
		$rs = $db->array_query ("SELECT $what FROM Articles A WHERE rating<>0 $where ORDER BY rating ASC LIMIT $limit");
		if (empty ($rs)) {
			$this->error = $db->report ("select fail");
			return false;
		}
		return $rs;
	}

	/**	Return articles according to counter, sorted from most visited to least.
	 *	@param	$limit	Number of articles to return.
	 *	@param	$what	Properties to get.
	 */
	function get_by_counter ($limit, $what="A.id, A.title, A.counter", $where="") {
		global $db;
		if (!is_numeric ($limit))
			return false;
		$rs = $db->array_query ("SELECT $what FROM Articles A $where ORDER BY counter DESC LIMIT $limit");
		if (empty ($rs)) {
			$this->error = $db->report ("select fail");
			return false;
		}
		return $rs;
	}

	/**	Article display counter advancing.
	 *	@param	$id		Article id.
	 *	@return number of affected rows
	 */
	function increase_counter ($id) {
		global $db;
		$db->exec ("UPDATE Articles SET counter=counter+1 WHERE id='$id'");
		return $db->get_affected_rows ();
	}
	
	/**	Update article rating.
	 *	Returns number of affected rows (should be 1), or false in case of db error or disabled rating
	 *	(display_extras == 0).
	 *	@param	$id		Article id.
	 *	@param	$rating	Rating to add.
	 */
	function update_rating ($id, $rating) {
		global $db;
		$old = $db->array_exec ("SELECT rating, num_rated, display_extras FROM Articles WHERE id='$id'");
		if ($old[0]['display_extras'] == '0')
			return false;
		$old_rating = $old[0]['rating'];
		$old_num_rated = $old[0]['num_rated'];
		$new_num_rated = $old_num_rated + 1;
		$new_rating = ($old_rating*$old_num_rated+$rating) / $new_num_rated;
		$rs = $db->exec ("UPDATE Articles SET rating='$new_rating', num_rated='$new_num_rated'
			WHERE id='$id' AND display_extras='1'");
		return $rs ? $db->get_affected_rows () : false;
	}

	/**	Get number of comments for given article.
	 *	@param	$id		Article id.
	 *	@return	integer
	 */
	function get_num_comments ($id) {
		global $db;
		$tmp = $db->array_exec ("SELECT count(*) as numc FROM Acomments WHERE article='$id'");
		return $tmp[0]["numc"];
	}
	
	/**	Insert article comment.
	 *	@param	$comment	Array ("article_id", "name", "subject", "email", "www", "text") with comment data.
	 *						Its keys must correspond to columns in db.
	 *	@return boolean, or insert id
	 *	@access public
	 */
	function insert_comment ($comment) {
		global $db;
		if (!is_array ($comment))
			return false;
		$comment["time"] = datetime ();
		$keys = array_reduce (array_keys ($comment), "string_reduce");
		foreach (array_keys ($comment) as $key)
			$comment[$key] = empty ($comment[$key]) ? "NULL" :
			"'". strip_html_tags ($comment[$key]) ."'";
		$values = array_reduce ($comment, "string_reduce");
		$rs = $db->exec ("INSERT INTO Acomments ($keys) VALUES ($values)");
		return $rs ? $db->last_insert_id ('acomments_id_seq') : false;
	}

	/**	Get comments for given article.
	 *	@param	$id		Article id.
	 *	@access	public
	 *	@return	integer
	 */
	function get_comments ($id) {
		global $db;
		$cms = $db->array_exec ("SELECT * FROM Acomments WHERE article='$id' ORDER BY time DESC");
		return $cms;
	}
	
	/**	Get specific comment data for given article.
	 *	@param	$article	Article id.
	 *	@param	$comment	Comment id.
	 *	@param	$data		String with comma separated values of requested comment data.
	 *	@access	public
	 *	@return	integer
	 */
	function get_comment ($article, $comment, $data="*") {
		global $db;
		$cms = $db->array_exec ("SELECT $data FROM Acomments WHERE 
			article='$article' AND id='$comment'");
		return $cms[0];
	}
	
	/**	Delete specific comment.
	 *	@param	$id		Comment id.
	 *	@access	public
	 *	@return	integer
	 */
	function delete_comment ($id) {
		global $db;
		$db->exec ("DELETE FROM Acomments WHERE id='$id'");
		return $db->get_affected_rows ();
	}
	
	/**	Returns all groups of given article.
	 *	@param	$aid	int		The 'id' value of an article.
	 *	@access	public
	 *	@returns array
	 */
	function get_all_groups ($aid, $what='G.id, G.name', $where='') {
		return $this->a_articles->get_all_groups ($aid, $what, $where);
	}

	
} // class client_articles
