<?php

/*
 *	Article System
 *	Online journal management tool written in PHP/MySQL/PostgreSQL.
 *	This code is available at http://sourceforge.net/projects/artsys
 *
 *	Copyright (C) 2001-2005 Jan Hnatek
 *	Distributed under the terms of the GNU General Public License
 *
 *	Date:	  05/08/2005
 *	Version:  0.6   	
 */

###############################################################################

/**
 *	Client part support for Article System.<br>
 *	Abstract class for client entity.
 *
 *	@author	Jan Hnatek
 *	@package client
 */
class client_entity {

    // VARIABLES
    //
	var $a_entity;
	var $a_images;
	// cache for last image : assignment data cached
	var $recent;

	// CONSTRUCTOR
	//
	function client_entity (&$a_ent, &$a_ima) {
		global $db;
		if (!is_object ($db))
			return false;
		$this->a_entity = $a_ent;
		$this->a_images = $a_ima;
		$this->recent = array ();
	}

	// ENTITY METHODS
	//
	/**	Return entity data of entity specified by given column name and it's value.
	 *	Returned data is <code>*</code> by default.<br>
	 *	@param	$col	Name of the column which $val is data from.
	 *	@param	$val	Value to specify the wanted group.
	 *	@param	$what	Columns to return.
	 *	@param	$where	Query restrictions.
	 *	@return asoc.array
	 */
	function get_by ($col, $val, $what="*", $where="") {
	 	return $this->a_entity->get_one ($what, "WHERE $col='$val' $where");
	}
	
	/**	Return entity-assigned image data.
	 *	@param	$id		Entity id.
	 *	@parama	$ident	Textual identificator.
	 */
	function get_image ($id, $ident) {
		$img = $this->get_image_assignment ($id, $ident);
		return $this->a_images->get_one_cached ($img["image"]);
	}
	
	/**	Return entity-assigned image id (assignment data).
	 *	Note: Results of this query are cached.
	 *	@param	$id		Entity id.
	 *	@parama	$ident	Textual identificator.
	 */
	function get_image_assignment ($id, $ident) {
		if ($this->recent["image"] == $id && $this->recent["ident"] == $ident)
			return $this->recent;
		else
			return $this->recent = $this->a_images->get_assigned ($this->a_entity->get_name (), $id, $ident);
	}

	/**	Return entity specific image tag.<br>
	 *	@param	$id		Entity id.
	 *	@param	$ident	Textual identificator.
	 *	@param	$bonus	Additional image properties.
	 */
	function get_image_tag ($id, $ident, $bonus='') {
		$img = $this->get_image_assignment ($id, $ident);
		if ($img) {
			// FIXME: ? detect size options just by 'width'
			if (preg_match ("/width/i", $img['options']))
				$size = '';
			else {
				$size = $this->a_images->get_size ($img['image']);
				$size = " ".$size[3];
			}
			return '<img src="'. $this->a_images->get_full_url ($img['image']) ."\"$size $bonus>";
		} else
			return false;
	}

	/**	Return entity specific image tag as a link, if available.<br>
	 *	@param	$id		Entity id.
	 *	@param	$ident	Textual identificator.
	 *	@param	$bonus	Additional image properties.
	 *	@param	$abonus	Additional anchor tag properties.
	 */
	function get_image_link ($id, $ident, $bonus='', $abonus='') {
		$img = $this->get_image_assignment ($id, $ident);
		if (!$img)
			return false;
		if (!$tag = $this->get_image_tag ($id, $ident, $bonus))
			return false;
		$dest = $this->a_images->get_destination ($img["image"]);
		if (empty ($dest))
			return $tag;
		return "<a href=\"$dest\" $abonus>$tag</a>";
	}

	/**	Duplicite with admin site (db_entity)! A HTML form select box renderer.<br>
	 *	Creates a select box based on the results of previous DB query.
	 *	@param	$name	Name of the select form item.
	 *	@param	$cval	Name of column or index to the query result, to be used as option's value="".
	 *	@param	$ctext	Name of column or index to the query result, to be used as option's label (text to display).
	 *	@param	$selected_value
	 *	TODO: ..
	 */
	// it wound be possible to do this using get_assoc and there wound be no need to call ->get explicitly,
	// but like this, it's more common (* can be selected, not just two columns, and can be still worked with) ???
	function select_box ($name, $cval, $ctext, $selected_value, $begin_options="", $end_options="", $attributes="") {
		$sb_array = array ();
		if ($begin_options != "")
			$sb_array = $begin_options;
		reset ($this->result);
		foreach ($this->result as $row)
			$sb_array[$row[$cval]] = $row[$ctext];
		if ($end_options != "")
			$sb_array = array_merge ($sb_array, $end_options);
		render_select_box ($name, $sb_array, $selected_value, $attributes);
	}	// select_box()

} // class
