<?php

/*
 *	Article System
 *	Online journal management tool written in PHP/MySQL/PostgreSQL.
 *	This code is available at http://sourceforge.net/projects/artsys
 *
 *	Copyright (C) 2001-2005 Jan Hnatek
 *	Distributed under the terms of the GNU General Public License
 *
 *	Date:	  05/08/2005
 *	Version:  0.6   	
 */

###############################################################################

/**
 *	Client part support for Article System.<br>
 *	Functions to handle groups on the client side.
 *
 *	@author	Jan Hnatek
 *	@package client
 */
class client_groups extends client_entity {

    // VARIABLES
    //
	var $a_articles;
	var $a_agroups;
	var $a_images;

	/**	Default columns to get with a db query */
	var $columns;

	var $error;

	// CONSTRUCTOR
	//
	function client_groups (&$art, &$gro, &$ima) {
		global $db;
		if (!is_object ($db))
			return false;
		$this->a_articles = $art;
		$this->a_agroups = $gro;
		$this->a_images = $ima;

		// satisfy parent class
		$this->a_entity = $this->a_agroups;

		// set default columns
		$this->columns = "id, parent, gorder, name, menu_text, description, intro, inline";
	}


	// GROUP METHODS
	//
	/**	Return list of exported article groups.
	 *	For each of them returns <code>$this->columns</code> data set.<br>
	 *	Default ordering by 'menu_text' ascending.
	 *	@param	$how	Optional WHERE/ORDER clause that overrides the default ordering.
	 *	@return array of asoc.arrays
	 */
	function get_all ($how="WHERE exported='1' ORDER BY menu_text ASC") {
		return $this->a_agroups->get ($this->columns, $how);
	}

	/**	Return group data of group specified by given column name and it's value.
	 *	Returned data is specified in <code>$this->columns</code>.<br>
	 *	@param	$col	Name of the column which $val is data from.
	 *	@param	$val	Value to specify the wanted group.
	 *	@return asoc.array
	 */
	function get_by ($col, $val) {
	 	return $this->a_agroups->get_one ($this->columns, "WHERE exported='1' AND $col='$val'");
	}

	/**	Return data of group specified by id.
	 *	Returned data is specified in <code>$this->columns</code>.<br>
	 *	@param	$id	Id of a group.
	 *	@return asoc.array
	 */
	function get ($id) {
		return $this->get_by ('id', $id);
  	}

	/**	Return data of top level (root) group.
	 *	The data contains 'id, name, menu_text, description'.<br>
	 *	@return asoc.array
	 */
	function get_root () {
	 	return $this->a_agroups->get_one ($this->columns, 'WHERE parent IS NULL');
  	}

	/**	Returns basic data of articles of given group.
	 *	Namely 'A.id, A.title, A.menu_title, A.issue, U.name, A.preview', as this is the default for <code>get_group</code>.
	 *	The list is ordered by A.issue ascending.
	 *	@param	$id		Id of an issue
	 *	@param	$what	List of columns to get from Articles.
	 *	@return array of associative arrays
	 */
	function get_articles ($id, $what='A.id, A.title, A.menu_title, A.issue, U.name, A.preview,
		A.published_on, I.aorder', $order='') {
		return $this->a_articles->get_group ($id, $what, "AND A.published_on IS NOT NULL", $order);
	}

	/**	Returns data of groups with parent group of given id.
	 *	Namely <code>$this->columns</code>.
	 *	The list is ordered by <code>Agroups.gorder</code> value.
	 *	@param	$id	Id of an issue
	 *	@return array of associative arrays
	 */
	function get_groups ($id, $order="ORDER BY gorder") {
		return $this->a_agroups->get ($this->columns, "WHERE exported='1' AND parent='$id' $order");
	}
	
	/**	Alias for get_groups.
	 *	@see get_groups
	 */
	function get_children ($id, $order="ORDER BY gorder") {
		return $this->get_groups ($id, $order);
	}
	
} // class client_groups

