<?php

/*
 *	Article System
 *	Online journal management tool written in PHP/MySQL/PostgreSQL.
 *	This code is available at http://sourceforge.net/projects/artsys
 *
 *	Copyright (C) 2001-2005 Jan Hnatek
 *	Distributed under the terms of the GNU General Public License
 *
 *	Date:	  05/08/2005
 *	Version:  0.6   	
 */

###############################################################################

/**
 *	Client part support for Article System.<br>
 *	Functions to handle issues on the client side.
 *
 *	@author	Jan Hnatek
 *	@package client
 */
class client_issues extends client_entity {

    // VARIABLES
    //
	var $a_articles;
	var $a_issues;
	var $a_images;

	var $article;
	var $issue;

	var $error;

	// CONSTRUCTOR
	//
	function client_issues (&$art, &$iss, &$ima) {
		global $db;
		if (!is_object ($db))
			return false;
    	$this->a_articles = $art;
		$this->a_issues = $iss;
		$this->a_images = $ima;

		// satisfy parent class
		$this->a_entity =& $this->a_issues;
	}


	// ISSUE METHODS
	//
	/**	Returns data on a visible issue. Depending on the flags, it can be ISSUE_CURRENT only,
	 *	ISSUE_ARCHIVED issues, or both .. ISSUE_VISIBLE.
	 *	@param	$id		Id of the desired issue (not used with ISSUE_CURRENT flag)
	 *	@param	$flags	One of the folowing { ISSUE_CURRENT, ISSUE_ARCHIVED, ISSUE_VISIBLE }
	 *	where ISSUE_ARCHIVED | ISSUE_CURRENT == ISSUE_VISIBLE (the default)
	 *	@return associative array
	 */
	function get ($id=0, $flags=ISSUE_VISIBLE, $what="id, name, menu_title, subtitle") {
		if ($id == 0)
			$flags = ISSUE_CURRENT;
		switch ($flags) {
		case ISSUE_CURRENT: return $this->a_issues->get_one ($what, "WHERE current='1'");
		case ISSUE_ARCHIVED: return $this->a_issues->get_one ($what, "WHERE archived='1' AND id='$id'");		
		case ISSUE_VISIBLE: return $this->a_issues->get_one ($what, "WHERE id='$id' AND (current='1' OR archived='1')");
		}
	}

	/**	Returns next archived issue id from given $id.
	 *
	 */
	function get_next ($id, $flags) {
		// TODO:
		return $id +1;
	}

	/**	Returns previous archived issue id from given $id.
	 *
	 */
	function get_previous ($id, $flags) {
		// TODO:
		return $id -1;
	}

	/**	Returns data on archived issues.
	 *	@param	$bonus	String, that is appended to the query. Possibly for ORDER BY, ...
	 *	@return associative array
	 */
	function get_archive ($bonus='') {
		return $this->a_issues->get ('id, name, menu_title, subtitle, published_on', "WHERE archived='1' ". $bonus);
	}

	/**	Returns basic data of articles in given issue.
	 *	The list is ordered by 'iorder'.
	 *	@param	$id	Id of an issue
	 *	@return array of associative arrays
	 */
	function get_articles ($id) {
		return $this->a_articles->get_issue ($id, 'A.id, A.title, A.subtitle, A.preview, A.menu_title,
		A.menu_group, A.iorder, A.published_on, U.name');
	}

// OBSOLETE ?
//

	/**	Returns menu of given issue as linkset class.
	 *	The data contained are in form (menu_group, menu_title, menu_group, menu_title, ..) or
	 *	just plain array of menu_titles (menu_title, menu_title, ...).<br>
 	 *	The list is ordered by 'iorder'.<br><br>
	 *	Use <code>linkset</code> methods <code>get_plain</code> for menu_group items and
	 *	<code>get_link</code> for menu_title items.
	 *	@param	$id	Id of an issue
	 *	@param	$menu_group Boolean to specify, whether get 'menu_group' data too)
	 *	@return array of associative arrays
	 *	@see linkset
	 */
	function get_menu ($id, $menu_group=true) {
		$a_set = $this->a_articles->get_issue ($id, 'A.id, A.menu_title, A.menu_group');
		if (!$a_set) {
			$this->a_articles->error_report ();
			return false;
		}
		$links = array ();
		foreach ($a_set as $a) {
			if ($menu_group)
				array_push ($links, array ("", $a['menu_group']));
   			array_push ($links, array ($a['id'], $a['menu_title']));
   		}
		return new linkset ($links);
	}

	/**	Test if given issue id is of archived issue.
	 *	Use to prevent displaying of non-public issues.
	 *	@param	$id	Id of an issue
	 *	@return string
	 */
	function is_archived ($id) {
		// TODO
		return true;
	}

} // class client_issues
