<?php

/*
 *	Article System
 *	Online journal management tool written in PHP/MySQL/PostgreSQL.
 *	This code is available at http://sourceforge.net/projects/artsys
 *
 *	Copyright (C) 2001-2005 Jan Hnatek
 *	Distributed under the terms of the GNU General Public License
 *
 *	Date:	  05/08/2005
 *	Version:  0.6   	
 */

###############################################################################

/**
 *	Client site statistics tool.<br>
 *
 *	@author	Jan Hnatek
 *	@package client
 */
class stats {

	// VARIABLES
	//
	/**	Session variables prefix.	*/
	var $session_prefix;
	/** Id of user_agent for this session.	*/
	var $user_agent_id;
	/**	User agent string */
	var $user_agent;


	// CONSTRUCTOR
	//
	/**	Set session_var name, register user_agent and perform sweep(), if first in session.
	 */
	function stats ($user_agent, $session_prefix) {
		$this->session_prefix = $session_prefix;
		$this->user_agent = $user_agent;
		// sweep only once per session
		if (empty ($_SESSION[$this->session_prefix."id"])) {
			$this->user_agent_id = $this->update_user_agent ($user_agent);
			$_SESSION[$this->session_prefix."id"] = $this->user_agent_id;
			$this->sweep ();
			$_SESSION[$this->session_prefix."sweep"] = "done";
		} else {
			$this->user_agent_id = $_SESSION[$this->session_prefix."id"];
		}
	}
	
	
	// METHODS
	//	
	/** Insert user_agent entry into Stats_user_agent and log basic quantity of
	 *	requests from those various user agents.
	 *	Returns true if insertion of new unique was ok, false otherwise.
	 *	@returns boolean
	 */
	function add_unique ($id, $time) {
		global $db;
		$ip = $_SERVER['REMOTE_ADDR'];
		$nat = isset ($_SERVER['HTTP_X_FORWARDED_FOR']) ? "'{$_SERVER['HTTP_X_FORWARDED_FOR']}'" : "NULL";
		$natcons = ($nat == "NULL") ? 'AND nat_client IS NULL' : "AND nat_client=$nat";
		$host = gethostbyaddr ($ip);
		$exists = $db->array_query ("SELECT * FROM Stats_unique WHERE
			article='$id' AND ip='$ip' $natcons AND user_agent='".$this->user_agent_id."'");
		$ok = empty ($exists) ?
			$db->exec ("INSERT INTO Stats_unique (article, ip, nat_client, host, user_agent, time) 
				VALUES ('$id', '$ip', $nat, '$host', '".$this->user_agent_id."', '$time')") :
			false;
		// maybe inconsistent session and Stats_user_agent?
		// [ just simple fix to one reason of failure; pgsql specific error (integrity check failure)
		//   when switching db, user_agent does not exist, yet its id is in the session ]
		if (!$ok) {
			$this->user_agent_id = $this->update_user_agent ($this->user_agent);
			$_SESSION[$this->session_prefix."id"] = $this->user_agent_id;
		}
		return $ok ? true : false;		
	}
	

	/** Update Stats_unique rating - article can be rated once per session.
	 *	Returns true if update successful, false otherwise.
	 *	@returns boolean
	 */
	function unique_rating ($id) {
		global $db;
		$ip = $_SERVER["REMOTE_ADDR"]; 
		$nat = isset ($_SERVER['HTTP_X_FORWARDED_FOR']) ?
			"nat_client='{$_SERVER['HTTP_X_FORWARDED_FOR']}'" : 
			"nat_client IS NULL";
		$db->exec ("UPDATE Stats_unique SET rating='1' WHERE 
			article='$id' AND ip='$ip' AND $nat AND user_agent='".$this->user_agent_id."' AND rating='0'");
		return $db->get_affected_rows () ? true : false;
	}


	/** Insert user_agent entry into Stats_user_agent and log basic quantity of
	 *	requests from those various user agents.
	 *	Returns id of newly inserted user_agent or id of already existing one.
	 *	@return int
	 */
	function update_user_agent ($user_agent) {
		global $db;
		$current = $db->array_query ("SELECT id FROM Stats_user_agent WHERE text='$user_agent'");
		if (empty ($current)) {
			// new user agent, insert into db
			$ok = $db->exec ("INSERT INTO Stats_user_agent (text, quantity) VALUES ('$user_agent', '1')");
			return $ok ? $db->last_insert_id ("stats_user_agent_id_seq") : false;
		} else {
			// exists already, increase quantity
			$db->exec ("UPDATE Stats_user_agent SET quantity=quantity+1 WHERE id='".$current[0]["id"]."'");
			return $current[0]["id"];
		}
	}

	/**	Remove entries with old timestamps.
	 *	Returns number of deleted rows.
	 *	@return	int
	 */
	function sweep () {
		global $db, $config;
		$old = time () - $config["unique_lifetime"];
		$db->open ();
		$rs = $db->exec ("DELETE FROM Stats_unique WHERE time < $old");
		return $db->get_affected_rows ();
	}

}	// class stats
