<?php

/*
 *	Article System
 *	Online journal management tool written in PHP/MySQL/PostgreSQL.
 *	This code is available at http://sourceforge.net/projects/artsys
 *
 *	Copyright (C) 2001-2005 Jan Hnatek
 *	Distributed under the terms of the GNU General Public License
 *
 *	Date:	  05/08/2005
 *	Version:  0.6   	
 */

###############################################################################

/**
 *	An object to work with MySQL database.<br>
 *	Includes functions to connect, exec queries, return results, close...
 *
 *	@author	Jan Hnatek
 *	@package db
 */

class mysql_db extends abstract_db {
//--------------------------------//

	// CONSTRUCTOR
	//

	/** Calls <code>abstract_db</code> contructor.
	 *	Sets up array return type to <code>MYSQL_ASSOC</code> by default.
	 */
	function mysql_db ($iname, $ihost, $iuser, $ipasswd, $array_return_type="ASSOC") {
		abstract_db::abstract_db ($iname, $ihost, $iuser, $ipasswd);
		$this->NUM = MYSQL_NUM;
		$this->ASSOC = MYSQL_ASSOC;
		$this->BOTH = MYSQL_BOTH;		
		$this->set_array_return_type ($array_return_type);
	}


	// METHODS
	//

	/**	Open a database connection.
	 *	@param $persist Say whether open a persistent database connection or not (1/0).
	 *	@access	public
	 *	@return	DB connection object
	 */
	function open ($persist=0) {
		$this->persistent = $persist;
		$this->conderror ($this->user, "mysql_db->open: database user not specified");
		if ($this->persistent == 1)
			$this->conn = mysql_pconnect ($this->host, $this->user, $this->password);
		else
			$this->conn = mysql_connect ($this->host, $this->user, $this->password);
		$this->conderror ($this->conn, "mysql_db->open: database connection failed");
		$this->conderror (mysql_select_db ($this->name, $this->conn), "mysql_db->open: failed to select database");
		return $this->conn;
	}

	/**	Close database connection.
	 *	@access	public
	 */
	function close () {
		//mysql_free_result ($this->rs);
		mysql_close ();
	}

	/**	Execute a database query. Store and return its result.
	 *	Add *any* value as the second parameter to display debug information on this particular query.
	 *	@access	public
	 *	@return query result or false when query failed
	 */
	function exec ($query) {
		$this->conderror ($query, "mysql_db->exec: no query given");
		// send number of arguments -1 to debug fn: per-query debug
		$tmp = func_num_args() - 1;
		$this->debug ($query, $tmp);
		$this->rs = mysql_query ($query, $this->conn);
		return $this->rs;
	}

	/**	Return number of rows in result
	 *	@access	public
	 */
	function num_rows () {
		// num_rows (-1 on error, 0 false too; non-zero OK)
		$x = ($this->rs) ? mysql_num_rows ($this->rs) : 0;
		if ($x == -1) {
			$this->debug ("mysql_db->num_rows: failed to get result (result == -1)");
			$x = 0;
		}
		return $x;
	}

	// WRAPPERS
	//
	/**	Wrapper, return result of <code>mysql_errno()</code>.
	 *	@access	public
	 */
	function errno () {
		return mysql_errno();
	}
	/**	Wrapper, return result of <code>mysql_error()</code>.
	 *	@access	public
	 */
	function error () {
		return mysql_error();
	}
	/**	Wrapper, return a result row as an enumerated array or FALSE.
	 *	@access	public
	 */
	function get_result () {
		return mysql_fetch_row ($this->rs);
	}

	/**	Wrapper, return a result row as an associative array, a numeric array, or both.<br>
	 *	The default is BOTH.
	 *	@access	public
	 */
	function get_result_array ($result_type = -1) {
		if ($result_type == -1)
			$result_type = $this->_array_return_type;
		return mysql_fetch_array ($this->rs, $result_type);
	}

	/**	Wrapper, return a result row as an object.
	 *	@access	public
	 */
	function get_result_object () {
		return mysql_fetch_object ($this->rs);
	}

	/**	Wrapper, return number of affected rows in previous operation.
	 *	@access	public
	 */
	function get_affected_rows () {
		return mysql_affected_rows ();
	}

	/**	Wrapper, return the id generated from the previous INSERT operation.
	 *	@access	public
	 */
	function last_insert_id () {
		return mysql_insert_id ($this->conn);
	}

	/**	Return uppercase identifier that this database constants start with.
	 *	Returns "MYSQL" string.
	 *	@access	public
	 */
	function get_db_id () {
		return "MYSQL";
  	}

	/**	Select the way the array data is returned.
	 *	Possible solutions are "NUM" for numeric, "ASSOC" for associative and "BOTH".
	 *	Given $type is converted to MYSQL_$type and evaluated.
	 *  @param	$type	one of "NUM", "ASSOC", "BOTH" strings
	 *	@access	public
	 */
	function set_array_return_type ($type="ASSOC") {
		if ($type == "NUM" || $type == "ASSOC" || $type == "BOTH") {
			$this->_array_return_type = $this->$type;
			return true;
		} else
			return false;
		}

} // class mysql_db

?>
