<?php

/*
 *	Article System
 *	Online journal management tool written in PHP/MySQL/PostgreSQL.
 *	This code is available at http://sourceforge.net/projects/artsys
 *
 *	Copyright (C) 2001-2005 Jan Hnatek
 *	Distributed under the terms of the GNU General Public License
 *
 *	Date:	  05/08/2005
 *	Version:  0.6   	
 */

###############################################################################

/**
 *	Abstract class for Articles entity in ArtSys DB.<br>
 *	Contains custom <code>SELECT</code> SQL queries.<br><br>
 *
 *	<b>Note: This is Article System specific class.</b>
 *
 *	@author	Jan Hnatek
 *	@package db_entities
 */
class db_articles extends db_entity {
//---------------------------------//

	// CONSTRUCTOR
	//

	/**	Contructor of db_articles class.<br>
	 *	@access	public
	 */
	function db_articles () {
		db_entity::db_entity ("Articles");
	}


	// METHODS : PUBLIC
	//
	
	/**	Returns all articles in given exported group.
	 *	// TODO: 'exported' value as parameter ???? in all group manip. functions ???
	 *	@param	$id		The 'id' value of a group.
	 *	@param	$what	Columns to return: select from { Articles A, Users U, Issues I }. Comma separated.
	 *	@access	public
	 *	@returns array
	 */
	function get_group ($id, $what='A.id, A.title, A.menu_title, A.issue, I.aorder, U.name', $where='',
		$order='ORDER BY I.aorder ASC') {
		global $db;
		$this->result = array ();
		$RS = $db->exec ("SELECT DISTINCT $what FROM Articles A, Users U, Agroups G, Ainsertion I
			WHERE (A.author=U.id) AND (A.id=I.article) AND (G.id=I.agroup) AND (G.id='$id') AND G.exported='1'
			$where $order"); //, 1);
		if (!$RS) {
			$this->error = $db->report (msg ("select fail"));
			return false;
		}
		while ($row = $db->get_result_array ())
			array_push ($this->result, $row);
		return $this->result;
	}

	/**	Returns all groups of given article.
	 *	@param	$aid	int		The 'id' value of an article.
	 *	@param	$what	string	Columns to get.
	 *	@param	$where	string	WHERE SQL constraint.
	 *	@access	public
	 *	@returns array
	 */
	function get_all_groups ($aid, $what='G.id, G.name', $where='') {
		global $db;
		$this->result = array ();
		$RS = $db->exec ("SELECT $what FROM Ainsertion A, Agroups G 
			WHERE article='$aid' AND A.agroup=G.id $where", 1);
		if (!$RS) {
			$this->error = $db->report (msg ("select fail"));
			return false;
		}
		while ($row = $db->get_result_array ())
			array_push ($this->result, $row);
		return $this->result;
	}

	/**	Returns true/false depending on whether given article is in given group.
	 *	@param	$aid	int		The 'id' value of an article.
	 *	@param	$gid	int		The 'id' value of a group.
	 *	@access	public
	 *	@returns boolean
	 */
	function is_in_group ($aid, $gid) {
		global $db;
		$db->exec ("SELECT * FROM Ainsertion WHERE (article='$aid') AND (agroup='$gid')", 1);
		return $db->num_rows ();
	}

	/**	Returns all related articles of given article.
	 *	@param	$aid	int		The 'id' value of an article.
	 *	@param	$what	string	Columns to return: select from { Articles }. Comma separated.
	 *	@access	public
	 *	@returns array
	 */
	function get_related ($aid, $what='A.id, A.title, A.menu_title') {
		global $db;
		$this->result = array ();
		//$RS = $db->exec ("SELECT this, that FROM Arelated WHERE this='$aid' OR that='$aid'", 1);
		$RS = $db->exec ("SELECT $what FROM Articles A, Arelated R WHERE
			(A.id=R.this AND that='$aid') OR (A.id=R.that AND this='$aid')"); //, 1);
		if (!$RS) {
			$this->error = $db->report (msg ("select fail"));
			return false;
		}
		while ($row = $db->get_result_array ())
			array_push ($this->result, $row);
		return $this->result;
	}

	/**	Returns true/false depending on whether given two articles are related
	 *	@param	$athis	int		The 'id' value of an article.
	 *	@param	$athat	int		The 'id' value of an article.
	 *	@access	public
	 *	@returns boolean
	 */
	function are_related ($athis, $athat) {
		global $db;
		$db->exec ("SELECT * FROM Arelated WHERE
			((this='$athis') AND (that='$athat')) OR ((this='$athat') AND (that='$athis'))", 1);
		return $db->num_rows ();
	}

	/**	Returns next article in an issue after given article, if any.
	 *	@param	$id		The 'id' value of an article.
	 *	@returns array
	 *	@access	public
	 */
	function get_next ($id, $what='id, title') {
		global $db;
		$tmp = $this->get_one ("id, issue, iorder", "WHERE id='$id'");
		if (!$tmp || empty ($tmp['issue']))
			return false;
		$next = $tmp['iorder']+1;
		return $this->get_one ($what, "WHERE issue='".$tmp['issue']."' AND iorder='$next'");
	}

	/**	Returns previous article in an issue after given article, if any.
	 *	@param	$id		The 'id' value of an article.
	 *	@returns array
	 *	@access	public
	 */
	function get_previous ($id, $what='id, title') {
		global $db;
		$tmp = $this->get_one ("id, issue, iorder", "WHERE id='$id'");
		if (!$tmp || empty ($tmp['issue']))
			return false;
		$next = $tmp['iorder']-1;
		return $this->get_one ($what, "WHERE issue='".$tmp['issue']."' AND iorder='$next'");
	}

	/**	Returns all articles in given issue.
	 *	@param	$issue	int		The 'id' value of an issue.
	 *	@param	$what	string	Columns to return: select from { Articles A, Users U, Issues I }. Comma separated.
	 *	@returns array
	 *	@access	public
	 */
	function get_issue ($issue, $what='A.id, A.title, A.menu_title, U.name') {
		global $db;
		$this->result = array ();
		// NOTE: could be specified by issue.namem it's unique
		// "SELECT A.id, A.title, U.name FROM Articles A, Users U WHERE A.author=U.id AND A.issue = '$iname'"
		$RS = $db->exec ("SELECT $what FROM Articles A, Users U, Issues I
			WHERE (A.author=U.id) AND (A.issue=I.id) AND (I.id='$issue')
			ORDER BY A.iorder"); //, 1);
		if (!$RS) {
			$this->error = $db->report (msg ("select fail"));
			return false;
		}
		while ($row = $db->get_result_array ())
			array_push ($this->result, $row);
		return $this->result;
	}
	
	/**	Returns all articles by given user.
	 *	@param	$user	int		The 'id' value of an user.
	 *	@param	$what	string	Columns to return: select from { Articles A, Users U, Issues I }. Comma separated.
	 *	@param	$where	string	Additional conditions to WHERE clause ("AND I.archived='1'")
	 *	@returns array
	 *	@access	public
	 */
	function get_by_user ($user, $what='A.id, A.title, A.menu_title, U.name', $where='') {
		global $db;
		$this->result = array ();
		$RS = $db->exec ("SELECT $what FROM Articles A, Users U, Issues I
			WHERE (A.author=U.id) AND (A.issue=I.id) AND (U.id='$user')
			$where ORDER BY A.id"); //, 1);
		if (!$RS) {
			$this->error = $db->report (msg ("select fail"));
			return false;
		}
		while ($row = $db->get_result_array ())
			array_push ($this->result, $row);
		return $this->result;
	}

	/**	Returns all 'new' articles, ie. articles, which are not in any issue.
	 *	@param	$what	string	Columns to return: select from { Articles A, Users U }. Comma separated.
	 *	@returns array
	 *	@access	public
     */
	function get_new ($what='A.id, A.title, U.name') {
		global $db;
		$this->result = array ();
		$RS = $db->exec ("SELECT $what FROM Articles A, Users U WHERE A.author=U.id AND A.issue IS NULL AND A.approved='1'"); //, 1);
		if (!$RS) {
			$this->error = $db->report (msg ("select fail"));
			return false;
		}
		while ($row = $db->get_result_array ())
			array_push ($this->result, $row);
		return $this->result;
	}

}	// class db_articles

?>
