<?php

/*
 *	Article System
 *	Online journal management tool written in PHP/MySQL/PostgreSQL.
 *	This code is available at http://sourceforge.net/projects/artsys
 *
 *	Copyright (C) 2001-2005 Jan Hnatek
 *	Distributed under the terms of the GNU General Public License
 *
 *	Date:	  05/08/2005
 *	Version:  0.6   	
 */

###############################################################################

/**
 *	Class for Images entity in ArtSys DB.<br>
 *	Contains custom <code>SELECT</code> SQL queries.<br>
 *	Images are stored in two directories on disk: image_dir and upload_dir.<br><br>
 *
 *	<b>Note: This is Article System specific class.</b>
 *
 *	@author	Jan Hnatek
 *	@package db_entities
 */
class db_images extends db_entity {
//-------------------------------//

	// VARIABLES
	//

	var $img_types = array (
		1 => "GIF", 2 => "JPG", 3 => "PNG",
		4 => "SWF", 5 => "PSD", 6 => "BMP"
	);
	var $image_dir;
	var $image_url;
	var $upload_dir;
	var $upload_url;
	// cache for last image : if cached, then all data (*)
	var $recent;


	// CONSTRUCTOR
	//

	/**	Contructor of db_images class.<br>
	 *	@access	public
	 */
	function db_images ($image_dir, $image_url, $upload_dir, $upload_url) {
		db_entity::db_entity ("Images");
		$this->image_dir = $image_dir;
		$this->image_url = $image_url;
		$this->upload_dir = $upload_dir;
		$this->upload_url = $upload_url;
		$this->recent = array (
			"id" => "",
			"filename" => ""
		);
	}


	// INFORMATIVE METHODS
	//

	/**	Like <code>get_one</code>, but it caches the results of the last query.
	 *	@param	$id	int	The 'id' value of the image.
	 *	@returns array
	 *	@access	public
	 */
	function get_one_cached ($id) {
		if (!isset ($this->recent) || $this->recent["id"] != $id) {
			if (!$this->get_one ('*', "WHERE id='$id'"))
				return false;
			$this->recent = $this->result[0];
		}
		return $this->result[0];
	}
	
	/**	Returns the filename of an image given by id.
	 *	@param	$id	int	The 'id' value of the image.
	 *	@access	public
	 *	@returns string
	 */
	function get_filename ($id) {
		$this->get_one_cached ($id);
		return $this->recent["filename"];
	}

	/**	Returns id of an image given by filename.
	 *	@param	$filename	The file name of the image.
	 *	@access	public
	 *	@returns string
	 */
	function get_id ($filename) {
		if (!isset ($this->recent) || $this->recent["filename"] != $filename) {
			if (!$this->get_one ("*", "WHERE filename='$filename'"))
				return false;
			$this->recent = $this->result[0];
		}
		return $this->recent["id"];
	}

	/**	Return image "href" parameter aka. its destination.
	 *	Note: this is not href of image itself, its href of a link, if this image is used an anchor.
	 *	@param	$id		Image id.
	 *	@access	public
	 */
	function get_destination ($id) {
		$this->get_one_cached ($id);
		return $this->recent["href"];
	}

	/**	Return image description.
	 *	@param	$id		Image id.
	 *	@access	public
	 */
	function get_description ($id) {
		$this->get_one_cached ($id);
		return $this->recent["description"];
	}

	/**	Return image assigned to given item (specified by $table, $id and $ident).
	 *	@param	$table	Table identificator (textual "Issues" / numeric "2")
	 *	@param	$id		Item id in given table.
	 *	@param	$ident	Textual identificator for this image.
	 *	@returns array
	 */
	function get_assigned ($table, $id, $ident) {
		global $db;
		$tabspec = $this->_assigned_specification ($table, $id);
		$idcol = $this->_assigned_column ($table);
		$col = $this->_assigned_title ($table);
		$RS = $db->exec ("SELECT IU.* FROM Iusage IU WHERE $tabspec AND (IU.ident='$ident')");
		if (!$RS) {
			$this->error = $db->report (msg ("select fail"));
			return false;
		}
		$this->result = $db->get_result_array ();
		return $this->result;
	}

	/**	Return all images assigned to given item (specified by $table & $id).
	 *	@param	$table	Table identificator (textual "Issues" / numeric "2")
	 *	@param	$id		Item id in given table.
	 *	@returns array
	 */
	function get_all_assigned ($table, $id) {
		global $db;
		$tabspec = $this->_assigned_specification ($table, $id, "IU.");
		$idcol = $this->_assigned_column ($table);
		$col = $this->_assigned_title ($table);
		if (empty ($col)) {
			$this->error = "table column name not found (table '$tablename')";
			return false;
		}
		$RS = $db->exec ("SELECT I.*, IU.ident, IU.options, N.$col AS assigned
			FROM $table N, Iusage IU, Images I WHERE $tabspec AND
			(N.id=IU.$idcol) AND (IU.image=I.id)
			ORDER BY I.filename", 1);
		if (!$RS) {
			$this->error = $db->report (msg ("select fail"));
			return false;
		}
		while ($row = $db->get_result_array ())
			array_push ($this->result, $row);
		return $this->result;
	}

	/**	Returns the URL path for an image given by id.
	 *	@param	$id		Image id.
	 *	@access	public
	 *	@returns string
	 */
	function get_url ($id) {
		return ($this->is_published ($id)) ? $this->image_url : $this->upload_url;
	}

	/**	Returns full URL for an image given by id.
	 *	@param	$id		Image id.
	 *	@access	public
	 *	@returns string
	 */
	function get_full_url ($id, $filename='', $uploaded='') {
		if ($uploaded == '')
			$uploaded = !$this->is_published ($id);
		if (empty ($filename))
			$filename = $this->get_filename ($id);
		return ($uploaded) ? $this->upload_url .'/'. $filename : $this->image_url .'/'. $filename;
	}

	/**	Returns the directory for an image given by id.
	 *	@param	$id		Image id.
	 *	@access	public
	 *	@returns string
	 */
	function get_dir ($id) {
		return ($this->is_published ($id)) ? $this->image_dir : $this->upload_dir;
	}

	/**	Returns full directory path for an image given by id.
	 *	@param	$id		Image id.
	 *	@access	public
	 *	@returns string
	 */
	function get_path ($id, $filename='', $uploaded='') {
		if ($uploaded == '')
			$uploaded = !$this->is_published ($id);
		if (empty ($filename))
			$filename = $this->get_filename ($id);
		return ($uploaded) ? $this->upload_dir .'/'. $filename : $this->image_dir .'/'. $filename;
	}

	/**	Return image tag.
	 *	@param	$id		Image id.
	 *	@param	$filename	Given filename of search one.
	 *	@access	public
	 */
	function get_tag ($id, $filename=null) {
		global $config;
		if (empty ($filename))
			$filename = $this->get_filename ($id);
		return '<img src="'. $this->get_url ($id) ."/$filename\">";
	}

	/**	Check physical existence of the image file on disk.
	 *	@param	$id		Image id.
	 *	@access	public
	 */
	function exists ($id) {
		return file_exists ($this->get_path ($id));
	}

	/**	Get state of the image file (it's either 'published' or 'uploaded').<br>
	 *	Returns true/false/-1 on error.
	 *	@param	$id		Image id.
	 *	@returns boolean
	 *	@access	public
	 */
	function is_published ($id) {
		if (!isset ($this->recent) || $this->recent["id"] != $id) {
			if (!$this->get_one ("*", "WHERE id='$id'"))
				return -1;
			$this->recent = $this->result[0];
		}
		return ($this->recent["uploaded"] == 0) ? true : false;
	}

	/**	Return array with image sizes. Try db first, then disk (fill db in this case).
	 *	The return value has same format as <code>getimagesize()<code>
	 *	@param	$id		Image id.
	 *	@returns array
	 *	@access	public
	 *	@see	getimagesize()
	 */
	function get_size ($id) {
		if (!isset ($this->recent) || $this->recent["id"] != $id) {
			if (!$this->get_one ("*", "WHERE id='$id'"))
				return -1;
			$this->recent = $this->result[0];
		}
		return $this->get_size_array ($id, $this->recent["width"], $this->recent["height"],
			$id, $this->recent["filetype"]);
	}

	/**	Return size array as PHP function <code>getimagesize()</code> for image existing in database.
	 *	Parse given arguments, if they are empty, read image params from disk and fill database.
	 *	@param	$id		Image id.
	 *	@param	$width	Image width.
	 *	@param	$height	Image height.
	 *	@param	$filetype	Image filetype (integer - index to $this->img_types)
	 *	@see    getimagesize()
	 */
	function get_size_array ($id, $width, $height, $filetype) {
		global $db;
		if (!empty ($width) && !empty ($height))
			// return given data (from db?)
			$img = array ($width, $height, $filetype, 'width="'.$width.'" height="'.$height.'"');
		else {
			// read image data from disk and fill db
			$path = $this->get_path ($id);
			$img = getimagesize ($path);
			$filesize = filesize ($path);
			if ($img && $filesize) {
				$db->exec ("UPDATE ".$this->name." SET
					filesize='".$filesize."',
					filetype='".$img[2]."',
					width='".$img[0]."',
					height='".$img[1]."' WHERE id='$id';"); // , 1);
				info ($db->report ("update failed"));
			}
		}
		//debug ($img[0]."x".$img[1]);
		return $img;
	}

	/**	Return array with window sizes (// TODO: for detected browser) for a newly opened browser window.
	 *	@param	$w		Image width.
	 *	@param	$h		Image height.
	 *	@returns array
	 *	@access	public
	 */
	function get_window_size ($w, $h) {
		$w = ($w < 600) ? $w+48 : 640;
		$h = ($h < 400) ? $h+65 : 480;
		return array ($w, $h);
	}
	
	/**	Returns an associative array with letter for filter.
	 *	@returns array
	 *	@access	public
	 */
	function get_select_data (&$assoc) {
		for ($i='a'; $i < 'z'; $i++) 
			$assoc[$i] = $i;
		$assoc['z'] = 'z';
		for ($i=0; $i < 10; $i++)
			$assoc[$i] = $i;
		return $assoc;
	}


	// DATABASE MODIFICATIONS
	//
	
	/**	TODO	
	 */
	function insert_uploaded ($filename, $userid) {
		global $db;
		$db->exec ("INSERT INTO ".$this->name." (filename, published, uploaded, owner) VALUES
			('$filename', 0, 1, '$userid')");
		info ($db->report (msg("insert fail"), msg("saved")));
		return $db->rs;
	}

	/**	Assign image to given item (specified by $table & $id).
	 *	@param	$input	Array of data that suits Iusage table.
	 */
	function assign ($input) {
		global $db;
		$idcol = $this->_assigned_column ($input["table"]);
		$RS = $db->exec ("INSERT INTO Iusage
			($idcol, image, ident, options) VALUES
			('".$input['id']."', '".$input['image']."',
			 '".$input['ident']."', '".$input['options']."')
		");
		if (!$RS) {
			$this->error = $db->report (msg ("insert fail"));
			return false;
		}
		return true;
	}
	
	/**	Un-assign all images from given item.
	 *	@param	$table	Table identificator (textual "Issues" / numeric "2")
	 *	@param	$id		Item id in given table.
	 */
	function unassign_all ($table, $id) {
		global $db;
		$tabspec = $this->_assigned_specification ($table, $id);
		$RS = $db->exec ("DELETE FROM Iusage WHERE $tabspec");
		if (!$RS) {
			$this->error = $db->report (msg("delete fail"));
			return false;
		}
		return true;
	}

	/**	Move image to or from upload directory.
	 *	@param	$id			Image id.
	 *	@param	$to_uploads Boolean to set rename direction.
	 *	@access	private
	 *	@returns boolean
	 */
	function _move ($id, $to_uploads, $filename='') {
		global $db;
		if ($filename == '')
			$filename = $this->get_filename ($id);
		if ($to_uploads === true) {
			$from = $this->image_dir.'/'.$filename;
			$to = $this->upload_dir.'/'.$filename;
			$uploaded = '1';
		} elseif ($to_uploads === false) {
			$from = $this->upload_dir.'/'.$filename;
			$to = $this->image_dir.'/'.$filename;
			$uploaded = '0';
		} else {
			$this->error = "internal error";
			return false;
		}
		if (!rename ($from, $to)) {
			$this->error = $db->report (msg ("rename failed"));
			return false;
		} else {
			// rename ok, update db
			$RS = $db->exec ("UPDATE Images SET uploaded='$uploaded' WHERE id='$id'");
			if (!$RS) {
				$this->error = $db->report (msg ("update fail"));
				return false;
			}
			return true;
		}
	}
	
	/**	TODO
	 */
	function publish ($id, $filename='') {
		return $this->_move ($id, false, $filename);
	}
	
	/**	TODO
	 */
	function unpublish ($id) {
		return $this->_move ($id, true, $filename);
	}
	
	/**	TODO
	 */
	function rename ($id, $newfilename, $oldfilename) {
		if ($oldfilename == '')
			$oldfilename = $this->get_filename ($id);
		$dir = $this->get_dir ($id);
		return rename ("$dir/".$oldfilename, "$dir/".$newfilename);
	}

	/**	TODO
	 */
	// TODO: should update db ?
	// see ima_delete.php, take it from there
	function delete ($id, $path='') {
		if ($path == '')
			$path = $this->get_path ($id);
		return unlink ($path);
	}


	// BUTTONS
	//

	/**	Insert preview button for this image.<br>
	 *	Optional <code>$taset</code> attribute uses special "input.image_controls" value.
	 *	@param	$id		Image id.
	 *	@param	$path	Full image url (dir/filename).
	 *	@param	$w		Image width.
	 *	@param	$h		Image height.
	 *	@param	$use_taset Boolean, true to use global <code>$ASET_LIST</code> object to use for tag output.
	 *	@access	public
	 */
	function preview_button ($id, $url, $w, $h, $use_taset) {
		// FIXME: 
		global $ASET_LIST;
		$size = $this->get_window_size ($w, $h);
		$code = "winimg = window.open ('$url', 'winimg', 'width=30, height=50, resizable=yes, scrollbars=yes');
		 winimg.resizeTo (". $size[0] .",". $size[1] .");
		 winimg.focus();";
		if ($use_taset) {
			echo "<input \n", $ASET_LIST->get ("input.image_controls");
            echo " type=\"button\" value=\"". msg("image btn view") ."\" name=\"view\" \n onclick=\"$code\">";
		} else
			echo "<input \n class=\"button\" type=\"button\" value=\"". msg("image btn view") ."\" name=\"view\" \n onclick=\"$code\">";
	}

	/**	Insert 'use' button, that will feed target form item with the name of image given by id.
	 *	Optional <code>$taset</code> attribute uses special "input.image_controls" value.
	 *	@access	public
	 */
	function feed_form_button ($id, $filename, $form, $item) {
		// FIXME:
		global $ASET_LIST;
		$code = '';
		if (!empty ($form) && !empty ($item))
			$code = "window.opener.document.$form.elements['$item'].value = '$filename';";
		echo "<input \n", $ASET_LIST->get ("input.image_controls");
		echo " \n type=\"button\" value=\"". msg('use') ."\" name=\"submit\" onclick=\"$code\">";
	}


	// MISC
	//

	/**	Check, if the filename is unique (for both dirs).
	 *	@param	$filename		Image file name.
	 *	@returns boolean
	 *	@access	public
	 */
	function is_unique ($filename) {
		if ($this->get_one ("id", "WHERE filename='$filename'"))
			return false;
		else
			return true;
	}


		// PRIVATE METHODS
		//

		/**	TODO
		 */
		function _assigned_title ($tablename) {
			switch ($tablename) {
				case "Articles":	$col = "title"; break;
				case "Issues":		$col = "name"; break;
				case "Users":		$col = "name"; break;
				case "Agroups":		$col = "name"; break;
				default:	$col = ''; break;
			}
			return $col;
		}

		/**	Return part of db query specifying wanted id.
		 */
		function _assigned_specification ($tablename, $id, $pref=null) {
			$tstable = array (
				"article_id" => "IS NULL",
				"issue_id" => "IS NULL",
				"agroup_id" => "IS NULL",
				"user_id" => "IS NULL"
			);
			switch ($tablename) {
				case "Articles": $tstable["article_id"] = $id; break;
				case "Issues": $tstable["issue_id"] = $id; break;
				case "Agroups": $tstable["agroup_id"] = $id; break;
				case "Users": $tstable["user_id"] = $id; break;
			}
			$tabspec = '';
			while (list ($key, $val) = each ($tstable)) {
				$tabspec .= is_numeric ($val) ? "$pref$key='$val'" : "$pref$key $val";
				if ($key != "user_id")
					$tabspec .= " AND ";
			}
			return $tabspec;
		}
		
		/**	Return the name of the column containing id.
		 */
		function _assigned_column ($table) {
			return strtolower (substr ($table, 0, strlen ($table)-1)) ."_id";
		}

}	// class db_images

?>
