<?php

// package layout

/*
 *	Article System
 *	Online journal management tool written in PHP/MySQL/PostgreSQL.
 *	This code is available at http://sourceforge.net/projects/artsys
 *
 *	Copyright (C) 2001-2005 Jan Hnatek
 *	Distributed under the terms of the GNU General Public License
 *
 *	Date:	  05/08/2005
 *	Version:  0.6   	
 */

###############################################################################

	// global variables defined/used by this library
	//

	// DTD constants for use with $doc_DTD
	define("dtd_HTML4_Strict", '<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01//EN">');
	define("dtd_HTML4_Transitional", '<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN"');
	define("dtd_HTML4_Frameset", '<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Frameset//EN">');

	//define("dtd_HTML4_Strict", '<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01//EN" "http://www.w3.org/TR/html4/strict.dtd">');
	//define("dtd_HTML4_Transitional", '<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN" "http://www.w3.org/TR/html4/loose.dtd">');
	//define("dtd_HTML4_Frameset", '<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Frameset//EN" "http://www.w3.org/TR/html4/frameset.dtd">');

	// useful constants
	define("document_DateFormat", "j.n.Y");
	define("document_TimeFormat", "H:i:s");
	define("document_Key", "%key%");		// replacement string
	define("document_Value", "%value%");	// replacement string


/**
 *	Document class.<br>
 *	Helps rendering basic HTML content, like document definition, header and metas.<br>
 *	<br>
 *	Note: This class does not use tag_writer
 *	(it's useless until &lt;body&gt;, which is not rendered by this class)
 *
 *	@author	Jan Hnatek (original code: TaZ)
 *	@package layout
 */
class document {

	// VARIABLES
	//

	/**	Document type definition. */
	var $dtd;
	/**	Document title. */
	var $title;
	/**	Content type string. */
	var $content;

	/**	Document attribute arrays. */
	var $metas;
	var $styles;
	var $styles_alternate;
	var $scripts;


	// CONSTRUCTOR
	//

	/**	Set up the default values.
	 *	@param	$charset	Character set to use with content meta tag.
	 */
	function document ($charset="iso-8859-1") {
		$this->dtd = dtd_HTML4_Transitional;
		$this->title = "No title";
		$this->content = "text/html; charset=$charset";
		$this->metas = array ();
		$this->styles = array ();
        $this->styles_alternate = array ();
		$this->scripts = array ();
	}


		// METHODS : PRIVATE
		//

		/** Output an array.
		 *	Note: internal array counter of $arr will be changed
		 *	@param	$arr	General array you want to print.
		 *	@param	$format	Format specification:
				"%key%" in $line will be replaced by key name,
				"%value%" by key value
		 *	@access	private
		 */
		function _array_print ($arr, $format) {
			if (!is_array ($arr))
				return;
			reset($arr);
			while ($i = each($arr))
				echo (str_replace (array (document_Key, document_Value), array($i[0], $i[1]), $format));
		}

		/**	Extension for subclasses.
		 *	@access	private
		 */
 		function _default_metas () {
			$this->meta ("Content-Type", $this->content, "http-equiv");
			$this->meta ("Content-Style-Type", "text/css", "http-equiv");
			$this->_array_print ($this->metas, "\t".'<meta name="'.document_Key.'" content="'.document_Value.'">'."\n");
		}


	// METHODS : METAs generation : PUBLIC
	//

	/**	Create META tag.
	 *	@param	$name		meta name
	 *	@param	$content	meta content
	 *	@param	$type		meta type (http-equiv | name | null=name)
	 *	@param	$echo		directly print the meta
	 *	@access	public
	 */
	function meta ($name, $content, $type=null, $echo=true) {
		if (!isset ($type))
			$type = "name";
		$s = "\t<meta $type=\"$name\" content=\"$content\">\n";
		if ($echo)
			echo($s);
		return $s;
	}

	// some specific METAs

		/**	Adds "created" meta to doc's meta tags.
		 *	@param	$when	date of doc creation.
		 *	@access	public
		 */
		function created ($when) {
			$this->metas["created"] = $when;
		}

		/** Adds "author" meta to doc's meta tags.
		 * 	@param	$who	author string
		 *	@access	public
		 */
		function author ($who) {
			$this->metas["author"] = $who;
		}

		/** Adds "keywords" meta to doc's meta tags.
		 *	@param	$words	keywords (csv)
		 *	@access	public
		 */
		function keywords ($words) {
			$this->metas["keywords"] = $words;
		}

	/**	Add a style file to document header.
	 *	@param	$fn			filename (url) to include
	 *	@param	$alternate	if true, style is made alternate style
	 *	@param	$alt_title	title of alternate
	 *	@access	public
	 */
	function style ($fn, $alternate=false, $alt_title=null) {
		if (empty ($alternate) || empty ($alt_title))
			$this->styles[] = $fn;
		elseif ($alternate)
			$this->styles_alternate[$alt_title] = $fn;
		else
			$this->styles[$alt_title] = $fn;
	}

	/**	Add a script file to document header.
	 *	// TODO: support for other script languages (than JavaScript)
	 *	@param	$fn			filename (url) to include
	 */
	function script ($fn) {
		$this->scripts[] = $fn;
	}

	/**	Generate document header.
	 *	@access	public
	 */
	function begin() {
		// try to send content-type header
		if (! headers_sent())
			header("Content-Type: ".$this->content.";");
		else
			$this->metas["class.document warning"] = "Can't send Content-Type header!";
		// DTD
		echo ($this->dtd."\n");
		echo "<html>\n<head>\n";
		$this->_default_metas ();
		echo "\n\t<title>". $this->title ."</title>\n\n";
		// link [alternate] styles
		$this->_array_print ($this->styles, "\t".'<link rel="stylesheet" type="text/css" href="'.document_Value.'">'."\n");
		$this->_array_print ($this->styles_alternate, "\t".'<link rel="alternate stylesheet" title="'.document_Key.'" type="text/css" href="'.document_Value.'">'."\n");
		// scripts
		$this->_array_print ($this->scripts, "\t".'<script language="JavaScript" type="text/javascript" src="'.document_Value.'"></script>'."\n");
		echo "</head>\n\n";
	}

	/** Generate end of the document.
	 *	@access	public
	 */
	function end() {
		echo "\n</html>\n";
	}

}	// class document

?>
