<?php

/*
 *	Article System
 *	Online journal management tool written in PHP/MySQL/PostgreSQL.
 *	This code is available at http://sourceforge.net/projects/artsys
 *
 *	Copyright (C) 2001-2005 Jan Hnatek
 *	Distributed under the terms of the GNU General Public License
 *
 *	Date:	  05/08/2005
 *	Version:  0.6   	
 */

###############################################################################
# gui templates : globals
#

/**
 *	GUI class to help render the final HTML.<br>
 *	Based on <code>document</code> class, but "knows" more about artsys.
 *
 *	@author Jan Hnatek
 *	@package layout
 */
class gui extends document {
//------------------------//

	// VARIABLES
	//
	
	var $content_description;

	/**	National settings & language */
	var $charset;
	var $language;

	/** Tag attribute container. */
	var $taset;


	// CONSTRUCTOR
	//
	/**	Calls super class constructor and sets up some more things.
	 *	@param	$taset
	 *	@param	$lang
	 *	@param	$content_desc
	 */
	function gui (&$taset, $charset="iso-8859-1", $lang="en", $content_desc="") {
		document::document ($charset);
		$this->content_description = $content_desc;
		$this->language = $lang;
   		$this->taset = $taset;
	}


		// PRIVATE METHODS
		//

		/**	[Overridden] Sets up some more metas.
		*/
		function _default_metas () {
			document::_default_metas ();
			$this->meta ("Content-Language", $this->language, "http-equiv");
			$this->meta ("Cache-Control", "no-cache", "http-equiv");
			$this->meta ("Generator", "none");
			$this->meta ("Destription", $this->content_description);
		}

		/**	Custom <code>body</code> tag rendering.
		*	@access	private
		*/
		function _body () {
			echo "\n<!-- body : timecounter execution -->\n";
			echo "<body", $this->taset->get ("body"), ">\n";
		}


	// DOCUMENT PARTS RENDERING : PUBLIC : GENERAL
	//

	/**	[Overridden] Opens body tag.
	 */
	function begin () {
		document::begin ();
		$this->_body ();
	}

	/**	[Overridden] Closes body tag too.
	 */
	function end () {
		echo "\n\n</body>\n</html>\n";
	}

	/**	Include a script inline.
	 */
	function script_inline ($file) {
		global $config, $module, $section;
		echo "\n\t<!-- main : included inline script -->\n";
		echo "\t<script language=\"JavaScript\" type=\"text/javascript\">\n";
		echo "\t<!--\n";
		if (file_exists ($file))
			require ($file);
		else
			warning ("script file $file not found...");
		echo "\n\t-->\n\t</script>\n";
	}

	// DOCUMENT PARTS RENDERING : PUBLIC : MAIN WINDOW
	//

	/**	Render menu of the main document.
	 */
	function main_menu_begin () {
		echo "<!-- top : main menu -->\n";
		echo "<div id=\"top\">\n";
		echo "<table summary=\"menu\">\n";
		echo "<tr>";
	}

	/**	Close menu of the main document.
	 */
	function main_menu_end () {
		echo "</tr>\n</table>\n";
		echo "</div>\n\n";
	}

	/** Display context help
	 */
	function display_help ($contents, $show_help=true) {
		if ($show_help && $contents)
			echo '<div id="help" style="display: block;">';
		else
			echo '<div id="help" style="display: none;">';
		if (!$contents)
			$contents = msg('help not available');
?>
		<u><?= msg('help title') ?></u><br>
		<blockquote style="margin: 0 0 0 10px;">
			<?= $contents ?>
		</blockquote>
		</div>
<?	}

	/**	Render "main" part of the document - the included subsection data.
	 */
	function main_begin () {
		global $module, $section;
		// logo
?>
		<div id="logo" style="float: right; margin-right: 1em">
		<img src="gui/img/logo.gif"><br>
		<!-- <span class="author">Jan Hntek:2001-2004</span> -->
		</div>
<?
		// header block
		echo "\n<!-- sub : header -->\n";
		echo "<div id=\"head\">\n\t";
		echo "<p> &gt; ". msg($module) ." &gt; ". msg($section) ."</p>\n";
		echo "</div>\n\n\n\n";
		// main block
		echo "<div id=\"main\">\n";
		echo "<!-- ## sub : content begin  ############################################################################ -->\n\n";
	}

	/**	Close "main" part of the document.
	 */
	function main_end () {
		echo "\n\n<!-- ## sub : content end  ############################################################################## -->\n";
		echo "</div>\n";
	}

	// DOCUMENT PARTS RENDERING : PUBLIC : IMAGES WINDOW
	//

	/**	Render "main" part of images window.
	 */
	function images_begin () {
		echo "<div id=\"main\">\n";
		echo "<!-- ## sub : content begin  ############################################################################ -->\n\n";
	}

	/**	Close "main" part of images window.
	 */
	function images_end () {
		echo "\n\n<!-- ## sub : content end  ############################################################################## -->\n";
		echo "</div>\n";
	}


	// DOCUMENT : GENERAL MENU RENDERING
	//

		/**	Menu rendering function.
         *	Renders contents of a table (externally defined) as a menu.
		 *	@param	$items		The array of items for the menu table.
		 */
		function menu_modules ($items, $label="modules") {
			echo "<td id=\"modulemenu\">\n\n\t";
			echo "<p".$this->taset->get ("menu.desc")." style=\"text-align: right\">$label</p>\n\t";
			foreach ($items as $i) {
				if (!preg_match ("/[<>]/", $i))
					$i = "<a".$this->taset->get ("menu.inactive").">$i</a>";
				echo "$i<br>\n\t";
			}
			echo "\n</td>";
		}

		/** Render middle part of top menu - section buttons.
		 */
		function menu_sections ($items, $open_form, $label="sections") {
			echo "<td id=\"topmiddle\">\n\n";
			echo "<p".$this->taset->get ("menu.desc").">$label</p>\n";
			echo "<form name=\"items\" method=\"post\" action=\"main.php\">\n\n\t";
			echo "<table id=\"sectionmenu\">\n\t";
			echo "<tr>";
			foreach ($items as $i) {
				echo "<td>\n\t\t";
				echo "<div class=\"sectionimage\">\n\t\t";
				echo "$i\n\t\t";
				echo "</div>\n\t";
				echo "</td>";
			}
			echo "</table>\n\n";
			if ($open_form == false)
				echo "</form>\n";
			echo "</td>";
		}

		/** Render right part of top menu - info.
		 */
		function menu_info ($items, $label="info") {
			echo "<td id=\"info\">\n\n\t";
			echo "<p".$this->taset->get ("menu.desc").">$label</p>\n\t";
			foreach ($items as $i)
				echo preg_match ("/<form/", $i) ? "$i\n\t" : "$i<br>\n\t";
			echo "\n</td>";
		}

} // class

?>
