<?php

/*
 *	Article System
 *	Online journal management tool written in PHP/MySQL/PostgreSQL.
 *	This code is available at http://sourceforge.net/projects/artsys
 *
 *	Copyright (C) 2001-2005 Jan Hnatek
 *	Distributed under the terms of the GNU General Public License
 *
 *	Date:	  05/08/2005
 *	Version:  0.6   	
 */

###############################################################################

/**
 *	Tag Attribute Set.<br>
 *	A container for markup languages tag attributes.<br><br>
 *
 *	The idea if quite simple. Tag attributes are stored in an
 *	associative array. Tag names are keys to this array.
 *	Value can be a simple string with tag attributes, or an array of
 *	such strings. In that case, the values from the array are used
 *	repeatedly (cyclic).<br><br>
 *
 *	Optionally, you can be notified of missing tag definitions in a <code>taset</code>.
 *	This is done through <code>set_report_fn</code> function or a parameter to class constructor.
 *	If no such function is given, no notification appears.
 *
 *	@author		Jan Hnatek
 *	@version    2.0
 *	@package layout
 */
class taset {
//---------//

	// VARIABLES
	//

	/**	Attribute data container.
	 *	Associative array with tag names (or virtually any identifier) as keys
	 *	and tag attributes (or arrays of tag attributes) as values.
	 */
	var $_data;

	/** Reporting function name (string).
	 */
	var $_report_fn;


	// CONSTRUCTOR
	//

	/**	Get attribute data from given associative array.<br>
	 *	@param	$in			Attribute data in an asociative array.
	 *	@param	$report_fn	Name of the function to use to report errors.
	 *	@access	public
	 */
	function taset ($in=0, $report_fn="") {
		$this->_report_fn = $report_fn;
		$this->_data = (is_array ($in)) ? $in : array ();
	}


		// METHODS : PRIVATE
		//

		/** Reporting method.
		*	@access	private
		*/
		function _report ($msg) {
			if (!empty ($this->_report_fn))
				eval ($this->_report_fn." (\$msg);");
		}


	// METHODS : PUBLIC
	//

	/**	Modify attribute data for given tag.
	 *	@param	$tag	string	Name of the tag to modify.
	 *	@param	$attrib	string	New attributes for this tag.
	 *	@access	public
	 */
	function set ($tag, $attrib) {
		$this->_data[$tag] = $attrib;
	}

	/**	Returns attribute data for given tag with a preceeding space character.
	 *	If the tag data is an array, <code>get</code> repeatedly returns next unused value from that array.
	 *	May return error/warning message based on <code>$report_fn</code> constructor value.
	 *	@param	$tag	string	Name of the tag to get.
	 *	@access	public
	 */
	function get ($tag) {
		// empty value
		if (!$this->exists ($tag))
			return $this->_report ("taset::get: no definition for tag: '$tag'");
		$tmp =& $this->_data[$tag];
		// prevent errors with '.' in tag name
        $tag = preg_replace ("/\./", "__", $tag);
		// pointer to a dynamic local variable - array pointer
		$pointer_name = "\$this->${tag}_pointer";
		eval ("\$p =& $pointer_name;");
		if (is_array ($tmp)) {
			// array
			if (!isset ($p))
				reset ($tmp);
			$p = current ($tmp);
			if (false === next ($tmp))
				reset ($tmp);
			$ret = " ".$p;
		} else
			// single value
			$ret = " ".$tmp;
		return ($ret == ' ') ? '' : $ret;
	}

	/**	Check existence of attributes for given tag. Empty tags ("") will fail too.
	 *	@param	$tag	string	Name of the tag to check.
	 *	@access	public
	 */
	function exists ($tag) {
		return in_array ($tag, array_keys ($this->_data));
	}

	/**	Set a function to use for reporting of missing tag definitions.
	 *	@access	public
	 */
	function set_report_fn ($report_fn) {
		$this->_report_fn = $report_fn;
	}

	/**	Set a function to use for reporting of missing tag definitions.
	 *	@return	string
	 *	@access	public
	 */
	function get_report_fn () {
		return $this->_report_fn;
	}

}	// class taset

?>
