<?php

/*
 *	Article System
 *	Online journal management tool written in PHP/MySQL/PostgreSQL.
 *	This code is available at http://sourceforge.net/projects/artsys
 *
 *	Copyright (C) 2001-2005 Jan Hnatek
 *	Distributed under the terms of the GNU General Public License
 *
 *	Date:	  05/08/2005
 *	Version:  0.6   	
 */

###############################################################################


/**
 *	A tool to retrieve data from various sources.<br><br>
 *
 *	Data is retrieved from a <code>abstract_db</code> object, that should
 *	contain a result resource from the last SELECT database call.
 *
 *	@author	Jan Hnatek
 *	@see	abstract_db
 *	@package lists
 */
class data_retriever_db extends data_retriever {
//--------------------------------------------//

	/**	Retrieve database data from result resource of given <code>abstract_db</code> object.
	 *	You should run a SELECT query on such object before retrieving data from it, otherwise
	 *	it fails (no resource data available).<br>
	 *	Returns false if something fails.
	 */
	function prepare (&$db) {
		if (!is_object ($db))
			return false;
		$rows = $db->num_rows ();
		if (($rows == -1) || ($rows == 0))
			return false;
		// create $data structure (2D array)
		for ($i=0; $i < $rows; $i++)
			// FIXME: after fixing abstract_db !!!
			if ($db->get_db_id() == "MYSQL")
				$this->_data[$i] = $db->get_result_array (MYSQL_NUM);
			elseif ($db->get_db_id() == "PGSQL")
				$this->_data[$i] = $db->get_result_array (PGSQL_NUM);
			else
				return false;
	}

}	// class data_retriever_db


//---------------------------------------------------------------------------//


/**
 *	A tool to retrieve data from various sources.<br><br>
 *
 *	Data is retrieved from a database, directly using PHP database API.<br>
 *	MySQL and PostgreSQL databases are supported.
 *
 *	@author	Jan Hnatek
 */
class data_retriever_db_direct extends data_retriever {
//---------------------------------------------------//

	/**	Retrieve data from database, directly using PHP DB API.
	 *	The <code>$data</code> structure is created here from a given database query result.<br>
	 *	Returns false if something fails.
	 *	@param	&$rs		reference to a database query result
	 *	@param	$db_type	type of database ("MYSQL" or "PGSQL" supported)
	 *	@access	public
	 */
    function prepare (&$rs, $db_type) {
		// check db_type and get number of results
		switch ($db_type) {
			case "mysql":
			case "MySQL":
				// test input
				if (is_resource($rs))
					return false;
				$rows = mysql_num_rows ($rs);
				if (($rows == -1) || ($rows == 0))
					return false;
				// create $data structure (2D array)
				for ($i=0; $i < $rows; $i++)
        			$this->_data[$i] = mysql_fetch_row ($rs);
				break;
    		case "pgsql":
			case "PGSQL":
				// test input
				if (!is_resource($rs))
					return false;
				$rows = pg_numrows ($rs);
				if (($rows == -1) || ($rows == 0))
					return false;
				// create $data structure (2D array)
				for ($i=0; $i < $rows; $i++)
        			$this->_data[$i] = pg_fetch_row ($rs, $i);
				break;
			default:
				error ("Database type not supported (use \"mysql\" or \"pgsql\")");
				return false;
		}
	}

}	// class data_retriever_db_direct


//---------------------------------------------------------------------------//


/**
 *	A tool to retrieve data from various sources.<br><br>
 *
 *	Data is retrieved from filesystem. Given a directory and a file mask,
 *	this class contains a list of files from that directory, that match the given mask.<br>
 *	Mask is expected to have format suitable for <code>preg_match</code> call (see PHP Manual).
 *
 *	@author	Jan Hnatek
 */
class data_retriever_fs extends data_retriever {
//--------------------------------------------//

	/** Retrieves filesystem data from given directory based on a file mask.<br>
	 *	Returns false if something fails.
	 *	@param	$dir		Directory, whose contains should be displayed;
	 *	@param	$mask		File name mask (PERL Regular Expression, see preg_match),
	 *			use '/.AST/' (where AST=='*') for all files.
	 *	@access	public
	 */
    function prepare ($dir, $regex_mask) {
		// read dir
		$d = dir($dir);
		//debug ("Handle: ".$d->handle."<br>\n");
		//debug ("Path: ".$d->path."<br>\n");
		$this->_data = array ();
		$i=0;
		while (false !== ($entry = $d->read()))
			if (($entry != "." && $entry != "..") && preg_match ($regex_mask, $entry)) {
				$row = array ($i++, $entry);
				array_push ($this->_data, $row);
			}
		$d->close();
	}

}	// class data_retriever_fs

?>
