<?php

/*
 *	Article System
 *	Online journal management tool written in PHP/MySQL/PostgreSQL.
 *	This code is available at http://sourceforge.net/projects/artsys
 *
 *	Copyright (C) 2001-2005 Jan Hnatek
 *	Distributed under the terms of the GNU General Public License
 *
 *	Date:	  05/08/2005
 *	Version:  0.6   	
 */

###############################################################################


/**
 *	The <code>image_browser</code> helps rendering the contents of a directory with images.<br>
 *	Uses <code>db_images</code> object.<br><br>
 *
 *	<b>Note: This is Article System specific class.</b>
 *
 *	@author	Jan Hnatek
 *	@see	db_images
 *	@package lists
 */
class image_browser extends list_table_limited {
//--------------------------------------------//

    // VARIABLES
	//

	/** Pointer to <code>db_images</code>.
	 *	@see	db_images
	 */
	var $db_images;

	/** External form name. */
	var $form;
	/** External form item name. */
	var $item;


	// CONSTRUCTOR
	//

	/**	Set up reference to <code>db_images</code> object and target form.<br>
	 *	Note that this object (unlike other <code>list_tables</code>) does not automatically
	 *	prepare its data. It has to be done explicitly with method <code>get_data</code>.<br>
	 *	@param	$db_images	An instance of <code>db_images</code> object.
	 *	@see	list_table_limited
	 */
	function image_browser (&$data, &$twriter, &$db_images, $session_var="list_pagenum") {
		$this->db_images = $db_images;
		list_table_limited::list_table_limited ($data, $twriter, $session_var);
	}


	// METHODS : PUBLIC
	//

	/**	Set usage of 'use' button.
	 *	That inserts image name into window.opener's form's item (textbox).
	 *	@param	$form	Name of the target form.
	 *	@param	$item	Name of the target form item.
	 */
	function use_usebutton ($form, $item) {
		$this->form = $form;
		$this->item = $item;
		debug ("form: $form; item: $item");
	}

	/**	Insert image browser button.<br>
	 *	Uses 'input.image_controls' taset value.
	 *	@access	public
	 */
	function browser_button ($form='', $item='') {
		global $config;
		$form = empty ($form) ? $this->form : $form;
		$item = empty ($item) ? $this->item : $item;
		$code = "ib = window.open('{$config["base_admin_url"]}/images.php?images_form=$form&images_item=$item',
		 'winimage', 'width=650, height=450, resizable=yes, scrollbars=yes'); ib.focus();";
		$this->_tw->open (array ("input", "input.image_controls"));
		echo " \n type=\"button\" name=\"image\" value=\"". msg('select') ."\" onclick=\"$code\">";
	}


		// METHODS : PRIVATE
		//

		/** [ Overridden ]
		 */
		function _table_row ($i) {
			global $images;
			// retrive special data from the last column
			$dbdata = $this->_data[$i][$this->_cols-1];

			$this->_tw->begin ("tr");
			// _cols-1 ... to have styled header of the last column with buttons
			for ($j=0; $j < $this->_cols-1; $j++) {
				$cell = $this->_data[$i][$j];
				if (($this->_draw_checkboxes) && (in_array ($j, $this->_chbox_cols))) {
					// render checkbox
					$this->_tw->begin ("td");
					?><input type="checkbox" value="<?= $cell?>" name="<?= $this->_chbox_prefix.$cell?>"><?
					$this->_tw->end ("td");
				} elseif (($this->_draw_boolean) && (in_array ($j, $this->_boolean_cols))) {
					// render boolean
					$cell = $cell ? $this->_boolean_true : $this->_boolean_false;
					$this->_tw->full ("td", $cell);
				} else {
					// render normally
					$this->_tw->full ("td", $cell);
				}
			}
			// last column, insert image controls
			$this->_tw->begin (array ("td", "td.image_controls"));
			// 'view' button
			$this->db_images->preview_button (
				$this->_data[$i][0],
				$this->db_images->get_full_url ($dbdata['id'], $dbdata['filename'], $dbdata['uploaded']),
				$dbdata['width'], $dbdata['height'], true);
			// optional 'use' button
			if (!empty ($this->item)) {
				$this->db_images->feed_form_button ($this->_data[$i][0], $dbdata['filename'],
					$this->form, $this->item);
			}
			// 'code' button
			// since rewrite
			// OBSOLETE: rewrite by default (public/article.php)
			//$code = htmlspecialchars ($this->db_images->get_tag ($this->_data[$i][0], $dbdata['filename']));
			$code = htmlspecialchars ("[img name=\"{$dbdata["filename"]}\"]");
			$this->_tw->open (array ("input", "input.image_controls"));
			echo "\n type=\"button\" value=\"". msg("image btn code") ."\" name=\"code\" \n onclick=\"set_img_code ('$code');\">";
			$this->_tw->end ("td", "tr");
		}

		/**	Outputs string with image code.<br>
		 * /
		function _img_code ($file, $sizes) {
			echo "<img src=\"$file\" $sizes>";
		} */

		/** [ Overridden ] <br>
		 *	Renders 'code' table.
		 */
		function _table_end () {
			$this->_tw->end ("table");
			$this->_code_table ();
			$this->_script_img_code ($this->_form_name);
		}

		/** [ Overridden ] <br>
		 *	Skiped select_all button, renders page_controls.
		 */
		function _table_foot () {
			if ($this->_pagecount > 1) {
				$this->_tw->begin (array ("tr", "tr.foot"));
				$this->_tw->open (array ("td", "td.foot"));
				echo " align=\"right\" colspan=\"$this->_cols\">";
				// if controls were not printed out
				if (!$this->page_controls ())
					// output fake content .. to force style usage
					echo "&nbsp;";
				$this->_tw->end ("td", "tr");
			}
		}

		/** Renders special 'code' table with input box, 'close' button, etc.
		 *	Special '*.img_code' taset values are used.
		 *	@access private
		 */
		function _code_table () {
			echo "<br>";
			echo "\n\n<!-- image_browser : code table begin -->\n";
			$this->_tw->begin (array ("table", "table.img_code"), array ("tr", "tr.img_code"));
			// code input
			$this->_tw->full (array ("td", "td.img_code"), msg("form image code"));
			$this->_tw->begin (array ("td", "td.img_code"));
			$this->_tw->open (array ("input", "input.img_code"));
			echo "\n type=\"text\" value=\"\" name=\"img_code\"";
			$this->_tw->end ("td", "tr");

			$this->_tw->begin (array ("tr", "tr.img_code"));
			$this->_tw->full ("td", "");
			$this->_tw->begin (array ("td", "td.img_code_buttons"));
			// submit button
			//$this->_tw->open (array ("input", "input.image_controls"));
			//echo "type=\"button\" value=\"submit\" name=\"submit\"";
			// close button
			$this->_tw->open (array ("input", "input.image_controls"));
			echo "value=\"". msg("close") ."\" name=\"close\" onclick=\"self.close ();\" size=5>&nbsp;";
			help (msg ("image code"));
			$this->_tw->end ("td", "tr", "table");
			echo "\n\n<!-- image_browser : code table end -->\n";
		}

		/**	Outputs javascript that fills 'code' input box.
		 *	@access private
		 */
		function _script_img_code () { ?>
			<script language="JavaScript1.1" type="text/javascript">
			<!--
			function set_img_code (img_tag) {
				document.<?= $this->_form_name?>.img_code.value = img_tag;
			}
			-->
			</script>
<?		}

}	// class image_browser

?>
