<?php

/*
 *	Article System
 *	Online journal management tool written in PHP/MySQL/PostgreSQL.
 *	This code is available at http://sourceforge.net/projects/artsys
 *
 *	Copyright (C) 2001-2005 Jan Hnatek
 *	Distributed under the terms of the GNU General Public License
 *
 *	Date:	  05/08/2005
 *	Version:  0.6   	
 */

###############################################################################
# list_table_limited : a class to render structured data into a table
#

/**
 *	The <code>list_table_limited</code> is modified <code>list_table</code>, with
 *	option to limit the amount of rows on the page. Output is then separated into
 *	several pages. Page browsing controls are included.<br>
 *
 *	@version	0.3, 20.12.2002
 *	@author		Jan Hnatek
 *	@package lists
 */
class list_table_limited extends list_table {
//-----------------------------------------//


	// VARIABLES
	//

	/**	Current page number. */
	var $_page;
	/**	Number of rows on one page. */
	var $_pagesize;
	/**	Number of pages. Pages are numbered (0, _pagecount-1). */
	var $_pagecount;
	/**	Name of session variable. */
	var $_session_var;
	/**	Number of pages considered "much", ie. enough for displaying 'begin','end' buttons. */
	var $_muchlimit;
	/**	Number of direct page buttons displayed. */
	var $_numbuttons;
	/**	Button labels array. */
	var $_labels;


	// CONSTRUCTOR
	//

	/**	Set some defaults (pagesize == 25 rows), set session variable.
	 *	@param	$session_var	Custom name of session variable used to store page number.
	 */
	function list_table_limited (&$data, &$twriter, $session_var="list_pagenum") {
		list_table::list_table ($data, $twriter);
		$this->_session_var = $session_var;
		$this->_muchlimit = 6;
		$this->_numbuttons = 4;
		$this->_labels = array (
			"begin" => "<<",
			"end"	=> ">>",
			"prev"	=> "<",
			"next"	=> ">",
		);
		$this->set_pagesize (25);
	}


	// METHODS : PUBLIC
	//

	/**	Set number of rows on one page.
	 *	@param	$rows	Maximum number of rows per page.
	 *	@access	public
	 */
	function set_pagesize ($rows) {
		$this->_pagesize = $rows;
		$this->_pagecount = floor ($this->_rows / $this->_pagesize);
		if ($this->_rows % $this->_pagesize > 0)
			$this->_pagecount++;
		// recount $this->_page
		if (isset ($_GET[$this->_session_var])) {
			//debug ("GET:" .$_GET[$this->_session_var]);
			$this->_set_page ($_GET[$this->_session_var]);
		} elseif (isset($_SESSION[$this->_session_var])) {
			//debug ("SESSION:".$_SESSION[$this->_session_var]);
			$this->_set_page ($_SESSION[$this->_session_var]);
		} else {
			$this->_page = $_SESSION[$this->_session_var] = 0;
		}
		debug ("data: $this->_rows; pagesize: $rows; page: ".($this->_page+1)."/$this->_pagecount");
	}

	/**	Returns the pagesize value.
	 *	@access	public
	 */
	function get_pagesize () {
		return $this->_pagesize;
	}


 		// METHODS : PRIVATE
		//

		/**	Test that the desired page value is correct.
		 *	@param	$page	New page number (0, _pagecount-1).
		 *	@access	private
		 */
		function _try_page ($page) {
			//$page = floor ($page);
			if ($page <= 0) {
				return 0;
			} elseif ($page > $this->_pagecount-1) {
				//debug ("pagecount limit overflow: $page");
				return $this->_pagecount-1;
			} else
				return $page;
		}

		/**	Set page number.
		 *	@param	New page number.
		 *	@access	private
		 */
		function _set_page ($page) {
			return $this->_page = $this->_try_page ($page);
		}

		/**	Render table content - rows.
		 *	@access	private
		 */
		function _table_rows () {
			$from = $this->_page * $this->_pagesize;
			$to = min ($from + $this->_pagesize, $this->_rows);
			for ($i=$from; $i < $to; $i++) {
				$this->_table_row ($i);
			}
		}

		/**	Render table footer. Optional "select_all" checkbox.
		 *	Special "tr.foot" parameter is set with $lt;tr&gt; tag.
		 *	@access	private
		 */
		function _table_foot () {
			// optional select_all footer
			if ($this->_draw_select_all && $this->_rows) {
				$size = $this->_cols - 2;
				// set a special parameter with table row ..
				$this->_tw->begin (array ("tr", "tr.foot"), array ("td", "td.foot"));
				?><input type="checkbox" name="select_all" onclick="select_all_<?= $this->_form_name?> ()"><?
				$this->_tw->end ("td");
				$this->_tw->full (array("td", "td.foot"), $this->_select_all_text);
				$this->_tw->open (array("td", "td.foot"));
				echo " align=\"right\" colspan=\"$size\">";
				// if controls were not printed out
				if (!$this->page_controls ())
					// output fake content .. to force style usage
					echo "&nbsp;";
				$this->_tw->end ("td", "tr");
			}
		}

		/**	Render page controls.
		 *	Returns true if page controls were printed out, false otherwise.
		 *	@access	public
		 *	@returns boolean
		 */
		function page_controls () {
			echo "\n<!-- page controls begin -->\n";
			if ($this->_pagecount > 1) {
				$from = $this->_try_page (floor ($this->_page - $this->_numbuttons/2));
				$to = $this->_try_page ($from + $this->_numbuttons - 1);
				if ($this->_pagecount > $this->_muchlimit && $this->_page != 0 && $from > 0)
					$this->_page_button (0, $this->_labels["begin"]);
				if ($this->_pagecount >= $this->_numbuttons && $this->_page != 0
					&& $this->_numbuttons < 6)
					$this->_page_button ($this->_page - $this->_numbuttons, $this->_labels["prev"]);
				if ($to == $this->_page)
					$from = $this->_try_page ($from - 1);
				for ($i=$from; $i <= $to; $i++)
					$this->_page_button ($i, $i);
				if ($this->_pagecount >= $this->_numbuttons && $this->_page != $this->_pagecount-1
					&& $this->_numbuttons < 6)
					$this->_page_button ($this->_page + $this->_numbuttons, $this->_labels["next"]);
				if ($this->_pagecount > $this->_muchlimit && $to != $this->_pagecount-1)
					$this->_page_button ($this->_pagecount - 1, $this->_labels["end"]);
			}
			echo "\n<!-- page controls end -->\n";
			return ($this->_pagecount > 1) ? true : false;
		}

		/**	Render a page control button.
		 *	@param	$page	Page number == destination of this button.
		 *	@param	$label	Name of the button (link), string.
		 *	@access	private
		 */
		function _page_button ($page, $label) {
			global $PHP_SELF;
			$page = $this->_try_page ($page);
			$link = "$PHP_SELF?". $this->_session_var ."=$page";
			if ($this->_page == $label && is_numeric ($label))
				$this->_tw->open (array ("a", "a.button_current"));
			elseif (is_numeric ($label))
				$this->_tw->open (array ("a", "a.button_number"));
			else
				$this->_tw->open (array ("a", "a.button"));
			$label++;
			echo "\n\thref=\"$link\">$label</a>";
		}

}	// class list_table_limited

?>
