<?php

/*
 *	Article System
 *	Online journal management tool written in PHP/MySQL/PostgreSQL.
 *	This code is available at http://sourceforge.net/projects/artsys
 *
 *	Copyright (C) 2001-2005 Jan Hnatek
 *	Distributed under the terms of the GNU General Public License
 *
 *	Date:	  05/08/2005
 *	Version:  0.6   	
 */

###############################################################################

/**
 *	Artsys logging system.<br>
 *	Implements artsys-specific message rendering methods.
 *
 *	If the <code>$use_trigger_error</code> is set in the contructor,
 *	PHPs <code>trigger_error()</code> function is used to *display* messages.
 *	It only affects screen output of MLOG_NOTICE, MLOG_WARNING and MLOG_ERROR.
 *	File output is rendered in a custom way, and others are using
 *	PHPs <code>error_log</code> function.
 *
 *	@author	Jan Hnatek
 *	@package log
 */

class as_mlog extends mlog {
//------------------------//

	// PRIVATE : MESSAGE RENDERING METHODS
	//

	/**	Render message on screen, according to message type.
	 *	@param	$text	Message text.
	 *	@param	$type	Type of the message (MLOG_{NOTICE, WARNING, ERROR, DEBUG..}
	 *	@access	private
	 */
	function _render_screen ($text, $type) {
		if (empty ($text))
			return;
		switch ($type) {
		case MLOG_DEBUG:
			echo "\n<code class=\"db_debug\">$text</code><br>\n";
			break;
   		case MLOG_DEBUG_DB:
		case MLOG_DEBUG_DB_MASSIVE:
			echo "\n<code class=\"debug\"><b>QUERY:</b> $text</code><br>\n";
			break;
  		case MLOG_NOTICE:
	   		if ($this->external)
				user_error ($text, MLOG_NOTICE);
			else
				echo "<p class=\"info\">$text</p>\n";
			break;
   		case MLOG_WARNING:
	   		if ($this->external)
				user_error ($text, MLOG_WARNING);
			else
				echo "<p class=\"warning\">$text</p>\n";
			break;
   		case MLOG_ERROR:
	   		if ($this->external)
				user_error ($text, MLOG_ERROR);
			else
				echo "<p class=\"error\">$text</p>\n";
			break;
		}
	}

	/**	Render message and write to logfile, according to message type.
	 *	@param	$text	Message text.
	 *	@param	$type	Type of the message (MLOG_{NOTICE, WARNING, ERROR, DEBUG..}
	 *	@access	private
	 */
	function _render_file ($text, $type) {
		global $section, $subsection;
		if (!$this->lfp) {
			user_error ("log: invalid file pointer", MLOG_ERROR);
			return false;
   		}
		switch ($type) {
		case MLOG_DEBUG:	$tmp = "DEBUG    "; break;
   		case MLOG_DEBUG_DB:	$tmp = "DEBUG_DB "; break;
   		case MLOG_NOTICE:	$tmp = "NOTICE   "; break;
   		case MLOG_WARNING:	$tmp = "WARNING  "; break;
   		case MLOG_ERROR:	$tmp = "ERROR    "; break;
		}
		$ret = log_datetime() ." $tmp [$section:$subsection]: $text\n";
		return fwrite ($this->lfp, $ret);
	}

	/**	Render message and write to syslog, according to message type.
	 *	@param	$text	Message text.
	 *	@param	$type	Type of the message (MLOG_{NOTICE, WARNING, ERROR, DEBUG..}
	 *	@access	private
	 */
	function _render_syslog ($text, $type) {
		// FIXME: does not work ?
		global $section, $subsection;
		$text = "[$section:$subsection] $text";
		error_log ($text, 0);
	}

	/**	Render message and send to email, according to message type.
	 *	@param	$text	Message text.
	 *	@param	$type	Type of the message (MLOG_{NOTICE, WARNING, ERROR, DEBUG..}
	 *	@access	private
	 */
	function _render_email ($text, $type) {
		user_error ("log: not implemented yet", MLOG_NOTICE);
	}

	/**	Render message and send to debug host, according to message type.
	 *	@param	$text	Message text.
	 *	@param	$type	Type of the message (MLOG_{NOTICE, WARNING, ERROR, DEBUG..}
	 *	@access	private
	 */
	function _render_debug_host ($text, $type) {
		user_error ("log: not implemented yet", MLOG_NOTICE);
	}

} // class as_mlog

?>
