<?php

/*
 *	Article System
 *	Online journal management tool written in PHP/MySQL/PostgreSQL.
 *	This code is available at http://sourceforge.net/projects/artsys
 *
 *	Copyright (C) 2001-2005 Jan Hnatek
 *	Distributed under the terms of the GNU General Public License
 *
 *	Date:	  05/08/2005
 *	Version:  0.6   	
 */

###############################################################################

// DEBUG : uncomment this to get debug information
//define('MAILER_DEBUG', true);

function comma_separated ($x, $y) {
	return "$x,$y";
}

/**
 *	Mailer.<br>
 *	PHP <code>mail()</code> wrapper with some added functionality.
 *
 * Example:
 <pre>
 	$mailer = new mailer (true);
	$mailer->set_From ("admin@artsys");
	$mailer->set_ReplyTo ("trash@artsys");
	$mailer->send ($message, 'test mesidz', array ('test@artsys', 'test@artsys'));
 </pre>
 *	@author	Jan Hnatek
 *	@package mailer
 */
class mailer {
//----------//

	// VARIABLES
	//

	var $headers;

	var $to;
	var $from;
	var $replyto;
	var $cc;
	var $bcc;

	// CONSTRUCTOR
	//
	function mailer () {
		$this->headers = array ("X-Mailer: PHP/" . phpversion());
		$this->to = $this->from = $this->cc = $this->bcc = '';
	}


		// PRIVATE METHODS
		//
		
		/**	Error reporting wrapper. (Subclass and ) Rewrite it to suit your needs.
		 *	@private
		 *	@param		$message	message to print.
		 *	@return		void
		 */
		function _error ($message) {
			echo $message;
		}
		
		/**	Simple debug function for this class
		 *	@private
		 *	@param		$text	text to print.
		 *	@return		void
		 */
		function _debug ($text) {
			if (defined('MAILER_DEBUG'))
				echo "\n<code style=\"color:brown\">$text</code><br>\n";
		}
		
		/** Header formatting function.
		 *	@param		$header		Array of header lines to merge.
		 *	@access		private
		 *	@return 	string
		 */
   		function _header ($header) {
			$tmp = "";
			foreach ($header as $line) {
				$this->_debug ($line);
				$tmp .= "$line\r\n";
    		}
			return $tmp;
   		}
		
		/**
		 */
		function _merge ($array) {
			return is_array ($array) ? array_reduce ($array, "comma_separated") : $array;
		}


	// PUBLIC METHODS
	//
	
	/**	Send email message.
	 *	@param	$message	Message text.
	 *	@param	$subject	Subject.
	 *	@param	$to			To: direct recipient(s).
	 *	@param	$from		From: message author.
	 *	@param	$cc			Cc: carbon copy.
	 *	@param	$bcc		Bcc: blind carbon copy.
	 */
	function send ($message, $subject=null, $to=NULL, $from=NULL, $cc=NULL, $bcc=NULL) {
		if (is_null ($to))
			$to = $this->to;
		if (is_null ($from))
			$from = $this->from;
		if (is_null ($cc))
			$cc = $this->cc;
		if (is_null ($bcc))
			$bcc = $this->bcc;
		if (is_null ($to)) {
			$this->_error ("To: was not set");
			return false;
   		}
		$to = $this->_merge ($to);
		$this->_debug ("To: $to");

		// default headers first, still in array form
		$header = $this->headers;
		array_unshift ($header, "Bcc: ".$this->_merge ($bcc));
		array_unshift ($header, "Cc: ".$this->_merge ($cc));
		array_unshift ($header, "From: $from");
		$formatted_header = $this->_header ($header);
		$this->_debug ($formatted_header);

		// finally, send it
		$this->_debug ("sending message: '$subject' with body {\n<br>\n$message\n<br>}");
		if (mail ($to, $subject, $message, $formatted_header)) {
			$this->_debug ("successfully sent");
   			return true;
      	} else {
			$this->_debug ("error sending mail");
   			return false;
		}
	}

	function send_blind ($message, $subject='', $bcc=NULL, $to=NULL, $from=NULL) {
		return $this->send ($message, $subject, $to, $from, '', $bcc);
	}
	function set_To ($to) {
		$this->to = $to;
	}
	function set_From ($from) {
		$this->from = $from;
	}
	function set_ReplyTo ($replyto) {
		$this->$replyto = $replyto;
  	}
	function set_Cc ($cc) {
		$this->cc = $cc;
	}
	function set_Bcc ($bcc) {
		$this->bcc = $bcc;
	}
	function set_headers ($headers) {
	 	$this->headers = $headers;
	}
	function get_headers ($headers) {
	 	return $this->headers;
	}

} // class mailer

?>
