<?php

/*
 *	Article System
 *	Online journal management tool written in PHP/MySQL/PostgreSQL.
 *	This code is available at http://sourceforge.net/projects/artsys
 *
 *	Copyright (C) 2001-2005 Jan Hnatek
 *	Distributed under the terms of the GNU General Public License
 *
 *	Date:	  05/08/2005
 *	Version:  0.6   	
 */

###############################################################################
# UPLOAD : A CLASS TO HANDLE FILE UPLOADS
#

/* DEBUG: uncomment this to get debug information */
define('UPLOAD_DEBUG', true);


/**	
 *	A class to easily handle file uploads.
 *	
 *	@version	1.2, 24.1.2003
 *	@author		Jan Hnatek
 *	@package	upload
 */
class upload
//--------//
{

	// VARIABLES
	//
	
	/** Upload directory. */
	var $upload_dir;
	/** Label of the submit button. */
	var $submit;
	
	/**	Internal (temporary) file name. */
	var $_filedef = 'upload_file';
	
	/** Feature checking: extension check enable/disable. */
	var $check_ext = false;
	/** Array of accepted extensions. */
	var $extensions;	
	/** Feature checking: file type check enable/disable. */
	var $check_type = false;
	/** Array of accepted file types (ex.: "image/jpeg"). */
	var $types;	
	/** Feature checking: file size check enable/disable. */
	var $check_filesize = false;
	/** Maximum allowed file size. */
	var $maxsize;	
	/** Feature checking: image size check enable/disable. */
	var $check_imgsize = false;
	/** Maximum x size of an image. */
	var $maxx;
	/** Maximum y size of an image. */
	var $maxy;
	
	/** Specification of upload error. Index to $errors. */
	var $error;
	/** Array of possible upload errors with textual description of the error. */
	var $errors = array (
		"e_file" => "Input filename error (empty filename / nonexistent file / browser maxsize exceeded).",
		"e_size" => "Failed size check in this class.",
		"e_type" => "Wrong file type.",
		"e_ext"  => "Wrong file extension.",
		"e_imgs" => "Maximum size for image exceeded.",
		"e_copy" => "Failed to copy into destination directory.",
		"e_exist"=> "File already exists in destination folder.",
		"ok" 	 => "File succesfully uploaded.",
		""		 => ""
	);


	// CONSTRUCTOR
	//

	/**	Set up the upload directory and some defaults.
	 *	@param	$dir		upload directory (file destination)
	 *	@param	$maxsize	maximum allowable file size in kBytes ("0" here means no check)
	 *	@param	$errors		asoc.array of error messages, use only to redefine, take original as basis
	 */
    function upload ($dir, $maxsize="0", $ierrors='') {
		$this->upload_dir = $dir;
		if (is_array ($ierrors))
			$this->errors = $ierrors;
		if ($maxsize != "0") {
			$this->check_filesize = true;
			$this->maxsize = $maxsize;
		}
	}


	// PRIVATE METHODS
	//
		
		/**	Simple debug function for this class
		 *	@param	$text	text to print.
		 *	@access private		 
		 */
		function _debug ($text) {
			if (defined('UPLOAD_DEBUG'))
				echo "\n<code style=\"color:gray\">$text</code><br>\n";
		}
		
		/** Apply all given checks on the uploaded file (size, type ...). See <code>get_file</code> on return values.
		 *	@returns string
		 *	@access private		 
		 */
		function _check_file () {
			// extension check
			if ($this->check_ext) {
				$parts = preg_split ("/\.+/", strtolower ($_FILES[$this->_filedef]['name']) );
				$file_ext = $parts [count ($parts)-1];
				$this->_debug ("ext: ".$file_ext);
				if (!in_array ($file_ext, $this->extensions))
					return $this->error = "e_ext";
			}
			// type check
			if ($this->check_type) {
				$this->_debug ("type: ".$_FILES[$this->_filedef]['type']);
				if (!in_array ($_FILES[$this->_filedef]['type'], $this->types))
					return $this->error = "e_type";
			}
			// file size check
			if ($this->check_filesize) {
				$this->_debug ("size: ". filesize ($_FILES[$this->_filedef]['tmp_name'])/1024);
				if ($this->maxsize < filesize ($_FILES[$this->_filedef]['tmp_name'])/1024)
					return $this->error = "e_size";
			}
			// image size check
			if ($this->check_imgsize) {
				$size = GetImageSize ($_FILES[$this->_filedef]['tmp_name']);
				$this->_debug ("size x: $size[0]/$this->maxx, size y: $size[1]/$this->maxy");
				if (($size[0] > $this->maxx) || ($size[1] > $this->maxy))
					return $this->error = "e_imgs";
			}
			// check if file exists in destination
			if (file_exists ($this->upload_dir."/". strtolower ($_FILES[$this->_filedef]['name']) ))
				return $this->error = "e_exist";
			
			return $this->error = "ok";
		}


	// PUBLIC METHODS
	//
	
	/**	Enable extension check. Allow only given extensions.
	 *	@param	$exts	array of allowable file extensions
	 *	@access public
	 */
	function set_check_extension ($exts) {
		if (count ($exts)) {
			$this->check_ext = true;
			$this->extensions = $exts;
		} else
			$this->_debug ("no extensions given");
	}
	
	/**	Enable file type check. Allow only given types.
	 *	@param	$types	array of allowable file types
	 *	@access public
	 */
	function set_check_type ($types) {
		if (count ($types)) {
			$this->check_type = true;
			$this->types = $types;
		} else
			$this->_debug ("no types given");
	}
	
	/**	Enable checking of image sizes.
	 *	@param	$maxx	Maximum x size.
	 *	@param	$maxy	Maximum y size.
	 *	@access public
	 */
	function set_check_imgsize ($maxx, $maxy) {
		if ($maxx && $maxy) {
			$this->check_imgsize = true;
			$this->maxx = $maxx;
			$this->maxy = $maxy;
		} else
			$this->_debug ("wrong img size input");
	}
	
	/** Get the uploaded file. If the input values are set, apply all file tests and upload the given file.<br>
	 *	@returns string
	 *	@access public
 	 */
	function get_file () {
		// do we have file submitted ?
		if (isset ($_POST[$this->submit])) {
			$this->_debug ("name: ".$_FILES[$this->_filedef]['name']);
			$this->_debug ("tmp_name: ".$_FILES[$this->_filedef]['tmp_name']);
			$this->_debug ("upload_dir: ".$this->upload_dir);
			if (is_uploaded_file ($_FILES[$this->_filedef]['tmp_name'])) {
				// apply checks
				if ($this->_check_file () == "ok") {
					// move to upload dir and delete from tmp
					$OK = copy ($_FILES[$this->_filedef]['tmp_name'], 
						$this->upload_dir."/". strtolower ($_FILES[$this->_filedef]['name']) );
					unlink ($_FILES[$this->_filedef]['tmp_name']);
					if ($OK)	return $this->error = "ok";
					else		return $this->error = "e_copy";
				} else
					// checks failed
					return $this->error;
			} else {
				// no file available .. ???
				$this->_debug ("Possible file upload attack. Filename: " . $_FILES[$this->_filedef]['name']);
				return $this->error = "e_file";
			}
		}
	}
	
    /**	Returns text of the last error.
     *	@returns string
     *	@access public
     */
	function get_filename () {
		return $_FILES[$this->_filedef]['name'];
	}
	
    /**	Returns text of the last error.
     *	@returns string
     *	@access public
     */
	function get_error () {
		return $this->error;
	}
	
    /**	Prints formatted error message.
     *	Applications should call this function at a 'placeholder' that displays an error message if error occurs.
     *	@access public
     */
	function error_report () {
		if ($this->error)
			print ("<br>". $this->errors[$this->error]);
	}
	
	/**	Insert the script form with a table. Use it as an example of usage to write your own input form.
	 *	@param	$submit		name of the submit button
	 */
	function insert_form ($url, $submit="upload", $msg="send file", $table_attr="", $p_attr="") {
		$this->submit = $submit;?>
		<form method="post" enctype="multipart/form-data" action="<?= $url?>">
<?			// use browser filesize recommendations, in bytes ...
			if ($this->maxsize) : ?>
		<input type="hidden" name="MAX_FILE_SIZE" value="<?= $this->maxsize * 1024 ?>">
<?			endif; ?>
		<p class="menu" style="margin:4">&nbsp;<b>Upload:</b>&nbsp;
			<input type="file" size="40" name="<?= $this->_filedef?>" class="button"><input 
			type="submit" name="<?= $this->submit?>" value="<?= $msg?>" class="button">
		</form>
		</p>
<?	}


}	// class upload

?>
