<?php

/*
 *	Article System
 *	Online journal management tool written in PHP/MySQL/PostgreSQL.
 *	This code is available at http://sourceforge.net/projects/artsys
 *
 *	Copyright (C) 2001-2005 Jan Hnatek
 *	Distributed under the terms of the GNU General Public License
 *
 *	Date:	  05/08/2005
 *	Version:  0.6   	
 */

###############################################################################
# some non-config global variables

	$config["author"] = "Jan Hntek (hnilek@users.sourceforge.net)";


###############################################################################
# loggging & PHP error reporting

	require_once INCLUDE_DIR ."/log.php";

	// TODO: incorporate this into class.mlog.php
	if (DEBUG_LEVEL == 'MLOG_ALL' || DEBUG_LEVEL == 'MLOG_MASSIVE')
		error_reporting (E_ALL);
	elseif (DEBUG_LEVEL == 'MLOG_NONE')
		error_reporting (E_ERROR);
	else
		error_reporting (E_ERROR | E_WARNING | E_PARSE);


###############################################################################
# some very basic functions

	// script alert message
	// TODO: use msg() automatically ??
	function alert ($text) {
		return "<SCRIPT>alert('$text');</SCRIPT>\n";
	}

	// script alert message with run-away
	// (default location is the "list" part of current module)
	function alert_run ($text, $dest = "list") {
		return "<SCRIPT>alert('$text'); document.location.href='main.php?sec=$dest';</SCRIPT>\n";
	}

	// single quote quoting function
	function q ($text, $style="quotation") {
		return "<SPAN class=\"$style\">'".$text."'</SPAN>";
	}

	// simple hint/help system
	function help ($text) {
		global $img_counter;
		if (!empty ($text)) {
			if (!isset ($img_counter))
				$counter = 0;
			$name = "img".$img_counter++;
			?><img name="<?= $name?>" src="./gui/img/question.gif" alt="help" onclick="help_window('<?= $text?>')"
			onmouseover="hilite('<?= $name?>')" onmouseout="unhilite('<?= $name?>')" ><?
		}
	} // help

	// simple testing function
	function test ($value, $output) {
		if (!$value) {
			echo $output;
			return false;
		} else
			return true;
	}

	// return current date & time in DB format
	function datetime () {
		# '2001-11-18 20:52:00'
		return date ("Y-m-d H:i:s");
	}

	// return current date & time in log format
	function log_datetime () {
		# 'Jan 11 20:52:00'
		return date ("M d H:i:s");
	}

	// return current URL with new querystring variables
	function print_url ($path, $newvars) {
		$tmp = array_merge ($_GET, $newvars);
		foreach ($tmp as $key => $value)
			if (!is_null ($value))
				$out[] = is_int ($key) ?
					urlencode ($value) :
					urlencode ($key) .'='. urlencode ($value);
		return "$path?". implode ($out, '&');
	}
	
	// perl-like chop function
	// TODO: might be used on more places, check it (",", foreach ...when creating comma-separated list strings)
	function perl_chop (&$text) {
		return $text = substr ($text, 0, -1);
	}

	// base-2 logarithm
	function log2 ($var) {
		return 1/log(2) * log($var);
	}

	// test if bit represented by given power of 2
	// is set in binary representation of given decimal
	function  binary_isset ($var, $pow2) {
		$bit = log2 ($pow2);
		$tmp = decbin ($var);
		$index = strlen ($tmp) - $bit - 1;
		if ($index < 0 || $index > strlen ($tmp))
			return false;
		return $tmp[$index];;
	}
	
	// get time (for page rendering time counter)
	function getmicrotime () {
		list ($usec, $sec) = explode (" ", microtime ()); 
		return ((float)$usec + (float)$sec); 
	}
	
	// html rewriter: strip tags and some other things
	// TODO: merge to some html_rewriter class (with image src handling etc.)
	function strip_html_tags ($document) {
		$search = array ("'<script[^>]*?>.*?</script>'si",  // Strip out javascript
						"'<[\/\!]*?[^<>]*?>'si",           // Strip out html tags
						"'([\r\n])[\s]+'",                 // Strip out white space
						"'&(quot|#34);'i",                 // Replace html entities
						"'&(amp|#38);'i",
						"'&(lt|#60);'i",
						"'&(gt|#62);'i",
						"'&(nbsp|#160);'i",
						"'&(iexcl|#161);'i",
						"'&(cent|#162);'i",
						"'&(pound|#163);'i",
						"'&(copy|#169);'i",
						"'&#(\d+);'e");                    // evaluate as php
		$replace = array ("",
						"",
						"\\1",
						"\"",
						"&",
						"<",
						">",
						" ",
						chr(161),
						chr(162),
						chr(163),
						chr(169),
						"chr(\\1)");
		return preg_replace ($search, $replace, $document);
	}

	// function for reducing array to a list of [comma] separated values
	// usage: $result = array_reduce ($array, "string_reduce");
	function string_reduce ($v, $w, $sep=",") {
	    return empty ($v) ? $w : "$v$sep $w";
	}

	// remove all values with given $key from an array (associative, most likely)
	// returns possibly modified array
	// note: array_splice does not work with associative arrays!
	function array_cut ($rem_key, $array) {
		$res = array ();
		reset ($array);
		while (list ($key, $val) = each ($array)) {
			if ($key != $rem_key)
				$res[$key] = $val;
		}
		return $res;
	}

	// get contents of a file to a string and evaluate
	function read_file ($file, $preserved_globals=null) {
		global $config;
		if (is_scalar ($preserved_globals))
			failexit ("read_file: wrong input format, i want an array");
		if (!empty ($preserved_globals) && is_array ($preserved_globals)) {
			foreach ($preserved_globals as $var)
				global $$var;
		}
		// NOTE: addslashes destroys variable values
		$fcontents = implode ('', file ($file));
		$tmp = '';
		eval ("\$tmp = \"$fcontents\";");
		return $tmp;
	}

	// display results of the last db query into simple table
	function simple_dump () {
		global $db;
		if (!($num = $db->num_rows ())) {
			echo "<b>Result empty.</b>";
		} else {
			echo "<table border=1 cellpadding=2 cellspacing=0>";
			for ($j=0; $j<$num; $j++) {
				$row = $db->get_result ();
				echo "<tr>";
				for ($i=0; $i < count ($row); $i++)
					echo "<td style=\"font-size:8pt\">". $row[$i] . "</td>";
				echo "</tr>";
			}
			echo "</table>";
		}
	}
?>
