<?php

/*
 *	Article System
 *	Online journal management tool written in PHP/MySQL/PostgreSQL.
 *	This code is available at http://sourceforge.net/projects/artsys
 *
 *	Copyright (C) 2001-2005 Jan Hnatek
 *	Distributed under the terms of the GNU General Public License
 *
 *	Date:	  05/08/2005
 *	Version:  0.6   	
 */

###############################################################################

// NOTES on object system:
// * var $input not automatic
// * prepare() must return true to be display()-ed
// * form must be defined in module.ini as <section>.form = edit
//   form name is then form_<module>_<ini_value>

class form_articles_edit extends form_process {
//-------------------------------------------//

	var $input;
	
	function prepare () {
		global $user, $users, $section, $articles;

		if (isset ($_POST['id']))		$id =& $_POST['id'];	// from 'save' in edit
		elseif (isset ($_GET['id']))	$id =& $_GET['id'];		// from 'new'
		$list =& $_GET['list'];									// from list

		/* INPUT: edit types:
			1) new article => $section == 'new'
				+ save mode ... will save the article in DB and switch to author edit mode
					$actions = "save"
			2) edit article => $section == 'edit'
				a) author mode (author is not yet finished)
					$mode = "author"
				b) editor mode (author is finished, editor is cerrecting this article)
					$mode = "editor"
		 */

		if ($section == 'edit') {

			###############################################################################
			# 'edit' article
			
			// get INPUT : article id
			if (!$id)	// we can have the 'id' from 'new article'
				$id = get_first_from ($list);
			debug ("article id: $id");
			$ok = test ($id, alert_run (msg('not selected', 'article')));
			if (!$ok)
				return false;

			// get article data & create art["column"] structure ...
			$this->input = $articles->get_one ('*', "WHERE id='$id'");
			test ($this->input, alert_run (msg('select fail')));

			// test Articles.approved, Articles.editor_done & rights 
			// (edit, if the article is approved or ready to approval)
			if ($this->input['approved'])
				warning (msg('edit approved article'));
			if ($done = $this->input['editor_done'])
				warning (msg('edit finished article'));
			if ($done)
				test ($user->check_my ('a_approve'), alert_run (msg('no rights')));

			// test Articles.author_finished & rights, set editing mode
			if ($this->input['author_done']) {
				test ($user->check_my ('a_correct'), alert_run (msg('no rights')));
				$this->input['mode'] = 'editor';
				$this->input['next_state'] = msg('form Nextstate approval');
			} else {
				$this->input['mode'] = 'author';
				$this->input['next_state'] = msg('form Nextstate correction');
				// if i am not admin
				if ($user->group != 'admins')
					// check, that i am the author of the article
					test (($this->input['author'] == $user->id), alert_run (msg('no rights')));
				else
					// else, just tell admin, what's he doing
					test (($this->input['author'] == $user->id), msg('edit elses art'));
			}
			debug ('edit mode: '. $this->input['mode']);
			$this->input['author'] = $users->get_name ($this->input['author']);

		} elseif ($section == 'new') {

			###############################################################################
			# 'new' article
			
			// check rights
			test ($user->check_my ('a_create'), alert_run (msg('no rights')));
			// create input["column"] structure
			// this is important : set id to "" -> it's used to recognize "new" group
			$this->input = array (
				'id' => '',
				'author' => $user->id,
				'signature' => $user->signature,
				'sources' => '',	'igroup' => '',
				'title' => '',		'menu_title' => '',
				'subtitle' => '',	'preview' => '',
				'content' => '',	'display_extras' => 1,
				'keywords' => '',	'approved' => '',
				'author' => $users->get_name ($user->id),
				'mode' => 'author', 
				'next_state' => msg('form Nextstate correction')
			);

		} else
			failexit ('wrong section');
		return true;
	}


    function custom_check () {
		global $user;
		$this->_nonempty ('Title', msg('form Title error'));
		$this->_nonempty ('Content', msg('form Content error'));
		$this->_init_checkboxes (array ('Finished', 'Extras'));
		// handle second save when finished
		if ($this->values['Finished'] == 'on' && $this->values['SureFinished'] == '0') {
			if ($this->values['Mode'] == 'author') {
				// *** check a_correct in author mode
				if (!$user->check_my ('a_correct')) {
						$this->error ('Finished', msg('unable to edit1').'<br>'.msg('unable to edit2'));
						warning (msg('unable to edit0'));
						$this->values['SureFinished'] = '1';
				}
			} elseif ($this->values['Mode'] == 'editor') {
				// *** check a_approve in editor mode
				if (!$user->check_my ('a_approve')) {
						$this->error ('Finished', msg('unable to edit1').'<br>'.msg('unable to edit2'));
						warning (msg('unable to edit0'));
						$this->values['SureFinished'] = '1';
				}
			}
		}
	}

	function notification ($id) {
		global $config;
		debug ('sending notification');
		$mail_tool = new mailer_db ($config['admin_email']);
		$message = $mail_tool->compile_article_notification ($id);
		$rlist = $mail_tool->prepare_recipients_article ();
		$subject = msg('new article added') . $config['base_url'];
		if ($mail_tool->send_notification ($subject, $message, $rlist))
			info (msg('notification ok'));
		else
			warning (msg('notification failed'));
	}

	/* NOTES on update article
			"author" mode .. (or admin rights)
				if finished	.. update { title, content, signature, sources, author_done, finished_on } & redirect to 'list'
				else		.. update { title, content, signature, sources} & edit again
			"editor" mode ..
				if finished	.. update { title, content, editor_done } & redirect to 'list'
				else		.. update { title, content } & edit again
	*/
	function store_data () {
		global $user, $db;
		debug ('storing data');
		$date = datetime ();
		if ($user->check_my ('admin') && isset ($this->values['Author']))
			$author = $this->values['Author'];
		else
			$author = $user->id;
		if ($this->values['Id'] == '') {
			// *** 'new'
			// common part of query
			$q = "INSERT INTO Articles
				(title, subtitle, preview, content, sources, keywords, 
				 author, signature, created_on %COLS%) VALUES
				('{$this->values['Title']}',
				 '{$this->values['Subtitle']}',
				 '{$this->values['Preview']}',
				 '{$this->values['Content']}',
				 '{$this->values['Sources']}',
				 '{$this->values['Keywords']}',
				 '$author',
				 '{$this->values['Signature']}',
				 '$date' %VALUES%)";
			if (isset ($this->values['MenuTitle'])) {
				$q = preg_replace (
					array ('/%COLS%/', '/%VALUES%/'),
					array (', menu_title %COLS%', ", '{$this->values['MenuTitle']}' %VALUES%"), $q);
			}
			if ($user->check_my ('admin')) {
				$extras = isset ($this->values['Extras']) ? 1 : 0;
				$q = preg_replace (
					array ('/%COLS%/', '/%VALUES%/'),
					array (", display_extras %COLS%", ", '$extras' %VALUES%"), $q);
			}
			if ($this->values['Finished'] == 'on') {
				$q = preg_replace (
					array ('/%COLS%/', '/%VALUES%/'),
					array (", finished_on, author_done", ", '$date', '1'"), $q);
			} else
				$q = preg_replace (array ('/%COLS%/', '/%VALUES%/'), array ('', ''), $q);
			// insert the new article into DB
			$db->exec ($q, 1);
			warning ($db->report (msg('insert fail'), ''));

			$id = $db->last_insert_id ('articles_id_seq');
			// if finished was set, send notification and run away, else move to edit
			if ($this->values['Finished'] == 'on') {
				$this->notification ($id);
				print alert_run (msg('saved'));
			} else {
				print "<SCRIPT>document.location.href='main.php?sec=edit&id=$id'</SCRIPT>\n";
			}

		} else {
			// *** 'edit'
			// common part of query
			$q = "UPDATE Articles SET
				title='{$this->values['Title']}',
				subtitle='{$this->values['Subtitle']}',
				preview='{$this->values['Preview']}',
				content='{$this->values['Content']}',
				sources='{$this->values['Sources']}',
				keywords='{$this->values['Keywords']}',
				author='$author' ";
			if (isset ($this->values['MenuTitle'])) {
				$q .= ", menu_title='{$this->values['MenuTitle']}'";
			}
			if ($user->check_my ('admin')) {
				$extras = ($this->values['Extras'] == 'on') ? 1 : 0;
				$q .= ", display_extras='$extras'";
			}
			// update the article in DB according to edit mode and state of article
			// force signature update when $user has admin rights
			if ($this->values['Mode'] == 'author' || $user->check_my ('admin')) {
				// *** AUTHOR mode
				if ($this->values['Finished'] == 'on') {
					$db->exec ($q . ",
						signature='{$this->values["Signature"]}',
						finished_on='$date', author_done='1' WHERE id='{$this->values["Id"]}'"); // , 1);
					// (only) if author finishes, send notification
					if (!$user->check_my ('admin'))
						$this->notification ($this->values['Id']);
					info ($db->report (msg('update fail'), alert_run (msg('saved'))));
				} else {
					$db->exec ($q . ",
						signature='{$this->values["Signature"]}'
						WHERE id='{$this->values["Id"]}'"); // , 1);
					$this->values["Nextstate"] = msg("form Nextstate correction");
				}
			} elseif ($this->values['Mode'] == 'editor') {
				// *** EDITOR mode
				if ($this->values['Finished'] == 'on') {
					$db->exec ($q . ", edited_on='$date', editor_done='1' WHERE id='{$this->values["Id"]}'"); // , 1);
					info ($db->report (msg('update fail'), alert_run (msg('saved'))));
				} else {
					$db->exec ($q . " WHERE id='{$this->values["Id"]}'"); // , 1);
					$this->values['Nextstate'] = 'approval';
				}
			} else
				failexit ('wrong edit mode');
			info ($db->report (msg('update fail'), msg('saved')));
			$this->display_form ();
		} // 'edit' update
	} // store_data


    function display_form () {
		global $user, $users, $agroups, $db;
		$t = new form_hidden ($this, 'Id', $this->input["id"]);
		$t->display ();
		$t = new form_hidden ($this, 'Mode', $this->input["mode"]);
		$t->display ();
?>
		<input type="hidden" name="id" value="<?= $this->input["id"]?>">
		<table class="form">
		<?	// *** author
			// possibility to change author only for admin
			if ($user->check_my ('admin')) {
				$uoptions = $users->get_assoc ('id', 'name', $uoptions, 'ORDER by name');
				$t = new form_select ($this, 'Author', $uoptions, $user->id);
			} else
				$t = new form_plaintext ($this, 'Author', $this->input['author']);
		?>
			<tr><td><?	$t->description () ?></td>
				<td><?	$t->display (false);
						$this->error_report ($t->name);
						// display_extras
						$de = new form_checkbox ($this, 'Extras', $this->input['display_extras'], '');
						if ($de->visible ()) {
							echo '&nbsp;&nbsp;';
							$de->description ();
							$de->display ();
						}
				?></td>
			</tr>
			
		<?	// *** Title
			$t = new form_text ($this, 'Title', $this->input['title'], 'size="70"');
			$this->_display_item ($t);
			
			// *** MenuTitle
			$t = new form_text ($this, 'MenuTitle', $this->input['menu_title'], 'size="70"');
			$this->_display_item ($t);
		
			// *** Subtitle
			$t = new form_text ($this, 'Subtitle', $this->input['subtitle'], 'size="70"');
			$this->_display_item ($t);
			
			// prepare editors
			$rtext = new richedit ('items', '<img src="./gui/img/richedit.gif" alt="Richedit editor" border="0">');
			$fcke = new fckeditor ('items', '<img src="./gui/img/fckicon.jpg" alt="FCKEditor" border="0">');

			// *** Preview
			$t = new form_textarea ($this, 'Preview', $this->input['preview'], 'cols="70" rows="4" id="preview"');
			$t2 = new form_button ($this, 'PreviewP', 'p', "onclick=\"lines2para ('preview');\"
				style=\"margin-bottom: 5px;\"");
			if ($t->visible ()) :
		?>
			<tr><td><?	$t->description () ?></td>
				<td><table cellpadding="0" cellspacing="0" border="0">
					<tr><td><?	$t->display ();	?></td>
						<td valign="bottom" align="center" style="text-align: center; padding: 2px">
						<?	$t2->display (); ?><br>
						<?	// place a link to richedit
							$rtext->place ($t->input_name, 'wpreview');
							if (!isset ($rtext->error))
								echo ' <br>';
							//$rtext->error_report ();
							// place a link to FCKEditor
							$fcke->place ($t->input_name, 'wpreview');
							if (isset ($rtext->error) && isset ($fcke->error)) {
								help (msg('richtext unavailable'));
							}
							//$fcke->error_report ();
							$this->error_report ($t->name);
						?>
					</td></tr>
					</table>
				</td>
			</tr>
		<?	endif;
		
			// *** Content
			$t = new form_textarea ($this, 'Content', $this->input['content'], 'cols="70" rows="15" id="content"');
			$t2 = new form_button ($this, 'ContentP', 'p', "onclick=\"lines2para ('content');\"
				style=\"margin-bottom: 5px;\"");
		?>
			<tr><td><?	$t->description () ?></td>
				<td><table cellpadding="0" cellspacing="0" border="0">
					<tr><td><?	$t->display ();	
								$this->error_report ($t->name);
						?></td>
						<td valign="bottom" align="center" style="text-align: center; padding: 2px">
						<?	$t2->display (); ?><br>
						<?	// place a link to richedit
							$rtext->place ($t->input_name, 'wcontent');
							if (!isset ($rtext->error))
								echo ' <br>';
							//$rtext->error_report ();
							// place a link to FCKEditor
							$fcke->place ($t->input_name, 'wcontent');
							if (isset ($rtext->error) && isset ($fcke->error)) {
								help (msg('richtext unavailable'));
							}
							//$fcke->error_report ();
							$this->error_report ($t->name);
						?>
					</td></tr>
					</table>
				</td>
			</tr>
			
		<?	// *** Source
			$t = new form_textarea ($this, 'Sources', $this->input['sources'], 'cols="70" rows="3"');
			$this->_display_item ($t);
			
			// *** Keywords
			$t = new form_text ($this, 'Keywords', $this->input['keywords'], 'size="70"');
			$this->_display_item ($t);

			// *** Signature
			// edit signature : author mode only or with a_approve rights
			// DONE: ? saved only with admin rights :-)
			if (($this->input['mode'] == 'author') || ($user->check_my ('a_approve'))) {
				$t = new form_textarea ($this, 'Signature', $this->input['signature'], 'cols="60" rows="3"');
			} else
				$t = new form_plaintext ($this, 'Signature', $this->input['signature']);
			$this->_display_item ($t);

			// give finalize checkbox only if not approved
			// TODO?: separate states -> fits not well in the system!!
			if ($this->input['approved'] != 1) : ?>
			<tr><td colspan="2"><?
					$s = new form_string ($this, 'Nextstate', $this->input['next_state']); 
					$t = new form_checkbox ($this, 'Finished', '');
					$t->description ();
					echo " ";
					$s->display ();
					echo " ";
					$t->display ();
				?></td>
			</tr>
			<tr><td colspan="2"><?
						$this->error_report ($t->name);
						$t = new form_hidden ($this, 'SureFinished', '0');
						$t->display ();
				?></td>
			</tr>
		<?	endif; ?>
		</table>
		</form>
<?	}

} // class form_articles_edit

?>
