--
-- Article System : database dump
--


--------------------------------------------------------------------------------
-- User groups
--

DROP TABLE IF EXISTS Ugroups;
CREATE TABLE Ugroups (
    id INT(11) NOT NULL auto_increment,
    name VARCHAR(255) NOT NULL,
    
    -- rights
    
    -- read unpublished articles
    a_read TINYINT(1) DEFAULT '0' NOT NULL,
    -- submit new/edit own articles
    a_create TINYINT(1) DEFAULT '0' NOT NULL,
    -- edit and correct else's articles
    a_correct TINYINT(1) DEFAULT '0' NOT NULL,
    -- sign an article as finished for next issue, delete other's articles
    a_approve TINYINT(1) DEFAULT '0' NOT NULL,
    -- create, publish, ... issues
    issues TINYINT(1) DEFAULT '0' NOT NULL,
    -- users modification (add, delete, block)
    users TINYINT(1) DEFAULT '0' NOT NULL,
    -- groups modification (add, delete)
    agroups TINYINT(1) DEFAULT '0' NOT NULL,
    -- admin flag
	admin TINYINT(1) DEFAULT '0' NOT NULL,
      
    CONSTRAINT PK_Ugroups PRIMARY KEY (id),
    CONSTRAINT UNQ_ugroup_name UNIQUE KEY (name),
    UNIQUE INDEX IDX_Ugroups_id (id),
    UNIQUE INDEX IDX_Ugroups_name (name)
);
--										       r  cre cor app iss use agr adm
INSERT INTO Ugroups VALUES ('1','authors',    '1','1','0','0','0','0','0','0');
INSERT INTO Ugroups VALUES ('2','editors',    '1','1','1','0','0','0','0','0');
INSERT INTO Ugroups VALUES ('3','publishers', '1','1','1','1','1','0','1','0');
INSERT INTO Ugroups VALUES ('4','admins',     '1','1','1','1','1','1','1','1');



--------------------------------------------------------------------------------
-- Users
--

DROP TABLE IF EXISTS Users;
CREATE TABLE Users (
      id INT(11) NOT NULL auto_increment,
      name VARCHAR(255) NOT NULL,
      username VARCHAR(255) NOT NULL,
      email VARCHAR(255) NULL,
      signature VARCHAR(255) NULL,
      password VARCHAR(255) NOT NULL,
      blocked TINYINT(1) DEFAULT '0' NOT NULL,
      ugroup INT(11) DEFAULT '6' NOT NULL,

      language VARCHAR(10) DEFAULT 'en' NOT NULL,
      show_help TINYINT(1) DEFAULT '1' NOT NULL,
      page_size INT(4) DEFAULT '20' NOT NULL,
      notify_issues TINYINT(1) DEFAULT '0' NOT NULL,
      notify_articles TINYINT(1) DEFAULT '0' NOT NULL,

      CONSTRAINT PK_Users PRIMARY KEY (id),
      CONSTRAINT UNQ_username UNIQUE KEY (username),
      UNIQUE INDEX IDX_Users_id (id),
      UNIQUE INDEX IDX_Users_username (username)
);

-- root
INSERT INTO Users VALUES ('1','administrator',	'root', 'root@artsys','','d5fdd4f1765bcf3e9d19f42e8ac11066','0','4', 'en','1',25, '0','0');


--------------------------------------------------------------------------------
-- Article groups
--

DROP TABLE IF EXISTS Agroups;
CREATE TABLE Agroups (
	id INT(11) NOT NULL auto_increment,
	parent INT(11),
	  -- order among the same level groups
	gorder INT(4) DEFAULT '0' NOT NULL,
	
	name VARCHAR(255) NOT NULL,
	menu_text VARCHAR(255) NULL,
	description VARCHAR(255) NULL,
	intro text,
	  -- display contained articles inline
	inline TINYINT(1) DEFAULT '0' NOT NULL,
	  -- display at all
	exported TINYINT(1) DEFAULT '0' NOT NULL,
	
	CONSTRAINT PK_Agroups PRIMARY KEY (id),
	CONSTRAINT UK_Agroups_name_parent UNIQUE KEY (name, parent),
	UNIQUE INDEX IDX_Agroup_id (id)
);

INSERT INTO Agroups VALUES (1,NULL,0,'domains','domains','Top-level group - domain list','',0,1);
INSERT INTO Agroups VALUES (6,1,2,'menu','Menu','site navigation','',0,1);


--------------------------------------------------------------------------------
-- Articles
--

DROP TABLE IF EXISTS Articles;
CREATE TABLE Articles (
	id INT(11) NOT NULL auto_increment,
	
	title text NOT NULL,
	subtitle text NULL,
	preview text NULL,
	content mediumtext NOT NULL,
	keywords VARCHAR(255) NULL,
	sources text,
	counter INT(11) DEFAULT '0' NULL,
	rating DOUBLE DEFAULT '0' NULL,
	num_rated INT(11) DEFAULT '0' NULL,
	-- enables displaying of rating and comments
	display_extras TINYINT(1) DEFAULT '1',
	
	-- authorship
	author INT(11) DEFAULT '1' NOT NULL,
	editor INT(11) DEFAULT '1',
	publisher INT(11) DEFAULT '1',
	-- textual author information (default .. name from user with id==id_author)
	signature VARCHAR(255) NOT NULL,
	
	-- state information
	
    -- author has finished his work on the article
	author_done TINYINT(1) DEFAULT '0' NOT NULL,
	-- editor has finished his work on the article
	editor_done TINYINT(1) DEFAULT '0' NOT NULL,
	-- admin has approved the article
	approved TINYINT(1) DEFAULT '0' NOT NULL,
	-- article is published (group or issue)
	published TINYINT(1) DEFAULT '0' NOT NULL,

	-- dates
	created_on DATETIME NULL,
	finished_on DATETIME NULL,
	edited_on DATETIME NULL,
	approved_on DATETIME NULL, 
	published_on DATETIME NULL,
	
	-- issue / menu information
	
	-- issue id, if any
	issue INT(11) NULL,
	-- item name in the menu of an issue, default should be the title of this article
	menu_title VARCHAR(100) NOT NULL,
	-- issue group id, it's menu_text is taken as menu_group when publishing
	igroup INT(11) NULL,
	-- issue group name this article belongs to
	menu_group VARCHAR(255) NOT NULL,
	-- order in the menu of an issue
	iorder INT(4) DEFAULT '0' NOT NULL,
	
	CONSTRAINT PK_Articles PRIMARY KEY (id),
	UNIQUE INDEX IDX_Articles_id (id)
);	


--------------------------------------------------------------------------------
-- Ainsertion : articles in groups
--

DROP TABLE IF EXISTS Ainsertion;
CREATE TABLE Ainsertion (
	id INT(11) NOT NULL auto_increment,
	article INT(11) NOT NULL,
	agroup INT(11) NOT NULL,
	aorder INT(4) DEFAULT '1' NOT NULL,

	CONSTRAINT PK_Ainsertion PRIMARY KEY (id),
	CONSTRAINT UNQ_Ainsertion UNIQUE KEY (article, agroup, aorder),
	UNIQUE INDEX IDX_Ainsertion_id (id)
);


--------------------------------------------------------------------------------
-- Arelated
--

DROP TABLE IF EXISTS Arelated;
CREATE TABLE Arelated (
      this INT(11) NOT NULL,
      that INT(11) NOT NULL,
      
      CONSTRAINT UNQ_Arelated_1 UNIQUE (this, that),
      UNIQUE INDEX IDX_Arelated_this_that (this, that)
);


--------------------------------------------------------------------------------
-- Issues
--

DROP TABLE IF EXISTS Issues;
CREATE TABLE Issues (
      id INT(11) NOT NULL auto_increment,
      name VARCHAR(100) NOT NULL,
	  menu_title VARCHAR(100) NOT NULL,
      subtitle VARCHAR(100) NULL,
      -- this should be '1' only by currently active issue
	  volume INT(11) NULL,
	  current TINYINT(1) DEFAULT '0',
      -- issue can be current/archived/invisible
      archived TINYINT(1) DEFAULT '0',
      published_on DATETIME NOT NULL,

      CONSTRAINT PK_Issues PRIMARY KEY (id),
      CONSTRAINT UNQ_Issue_name UNIQUE KEY (name),
      UNIQUE INDEX IDX_Issues_id (id),
      UNIQUE INDEX IDX_Issues_name (name)
);


--------------------------------------------------------------------------------
-- Volumes
--

DROP TABLE IF EXISTS Volumes;
CREATE TABLE Volumes (
      id INT(11) NOT NULL auto_increment,
      name VARCHAR(100) NOT NULL,
      
      CONSTRAINT PK_Volumes PRIMARY KEY (id),
      CONSTRAINT UNQ_Volumes_name UNIQUE KEY (name),
      UNIQUE INDEX IDX_Volumes_id (id),
      UNIQUE INDEX IDX_Volumes_name (name)
);


--------------------------------------------------------------------------------
-- Images
--

DROP TABLE IF EXISTS Images;
CREATE TABLE Images (
      id INT(11) NOT NULL auto_increment,
      filename VARCHAR(100) NOT NULL,
	  -- owner : user id
	  owner INT(11) NOT NULL,
	  -- link href
	  href VARCHAR(255) DEFAULT NULL,
	  -- description
	  description text DEFAULT NULL,
	  
	  
      -- file placed in uploads directory
      uploaded TINYINT(1) DEFAULT '0',
      -- file placed in aimages directory
      published TINYINT(1) DEFAULT '0',
	  -- size information
	  filesize INT(4) DEFAULT NULL,
	  -- filetype: same format as in PHP (see PHP manual)
	  filetype INT(4) DEFAULT NULL,
	  width INT(4) DEFAULT NULL,
	  height INT(4) DEFAULT NULL,
	  
      -- image filename is unique for both directories
      CONSTRAINT PK_Images PRIMARY KEY (id),
      CONSTRAINT UNQ_Images_filename UNIQUE KEY (filename),
      UNIQUE INDEX IDX_Images_id (id),
      UNIQUE INDEX IDX_Images_name (filename)
);

INSERT INTO Images VALUES ('1','artsys.gif','1', 'http://artsys.sourceforge.net/','', '0','1', NULL,NULL,NULL,NULL);


--------------------------------------------------------------------------------
-- Images' usage
--

DROP TABLE IF EXISTS Iusage;
CREATE TABLE Iusage (
	id INT(11) NOT NULL auto_increment,
	-- these 4 should be set exclusively
	article_id INT(11) DEFAULT NULL,
	issue_id INT(11) DEFAULT NULL,
	agroup_id INT(11) DEFAULT NULL,
	user_id INT(11) DEFAULT NULL,
		
	image INT(11) NOT NULL,

	-- textual identificator (for simple recognition)
	ident VARCHAR(100) NOT NULL,
	-- additional options
	options VARCHAR(255) DEFAULT NULL,

	CONSTRAINT PK_Iusage PRIMARY KEY (id),
	CONSTRAINT UNQ_Iusage UNIQUE KEY (article_id, issue_id, agroup_id, user_id, image),
	UNIQUE INDEX ISX_Iusage_id (id)
);


--------------------------------------------------------------------------------
-- MailList
--

DROP TABLE IF EXISTS Maillist;
CREATE TABLE Maillist (
      id INT(11) NOT NULL auto_increment,
      email VARCHAR(255) NOT NULL,
      name VARCHAR(255) NULL,
      blocked TINYINT(1) NOT NULL,
      
      CONSTRAINT PK_Maillist PRIMARY KEY (id),
      UNIQUE INDEX IDX_Maillist_id (id)
);


--------------------------------------------------------------------------------
-- Sessions
--

DROP TABLE IF EXISTS Sessions;
CREATE TABLE Sessions (
    id VARCHAR(64) DEFAULT '0' NOT NULL,
    userid INT(11),
    username VARCHAR(255) NOT NULL,
	ip VARCHAR(255) NOT NULL,
    time INT(14),
    
    CONSTRAINT PK_Sessions PRIMARY KEY (id),
    UNIQUE INDEX IDX_Sessions_id (id)
);


--------------------------------------------------------------------------------
-- Statistics
--

DROP TABLE IF EXISTS Stats_user_agent;
CREATE TABLE Stats_user_agent (
	id INT(11) NOT NULL auto_increment,
	text VARCHAR(255) NOT NULL,
	quantity INT(11) DEFAULT '0',
	
	CONSTRAINT PK_Stats_user_agent PRIMARY KEY (id),
	CONSTRAINT UNQ_Stats_user_agent_text UNIQUE KEY (text),
	UNIQUE INDEX IDX_Stats_user_agent_id (id)
);

DROP TABLE IF EXISTS Stats_unique;
CREATE TABLE Stats_unique (
	article INT(11) NOT NULL,
	
	ip VARCHAR(255) NOT NULL,
	-- from $_SERVER["HTTP_X_FORWARDED_FOR"] if set
	nat_client VARCHAR(255) DEFAULT NULL,
	host VARCHAR(255) DEFAULT NULL,

	user_agent INT(11) NOT NULL,
	time INT(14) NOT NULL,
	-- rating flag
	rating TINYINT(1) DEFAULT '0',
	
	CONSTRAINT PK_Stats_unique PRIMARY KEY (article, ip, user_agent)
);


--------------------------------------------------------------------------------
-- Acomments
--

DROP TABLE IF EXISTS Acomments;
CREATE TABLE Acomments (
	id INT(11) NOT NULL auto_increment,
	-- article reference
	article INT(11) NOT NULL,
	-- re: .. comment reference
	reply_to INT(11) DEFAULT NULL,
	author VARCHAR(100) DEFAULT NULL,
	email VARCHAR(100) DEFAULT NULL,
	www VARCHAR(100) DEFAULT NULL,
	subject VARCHAR(255),
	content text NOT NULL,	
	time DATETIME NOT NULL,

	CONSTRAINT PK_Acomments PRIMARY KEY (id),
	UNIQUE INDEX IDX_Acomments_id (id)
);

